<!-- #include file="../../include/header.inc" -->
<table width=95%>
<tr>
<td valign=top><h2>Creating Your First Word File</h2>
</td>
<td align=right valign=top><img src="<%=vroot%>images/wordwriter.gif"></td>
</tr>
</table>
<hr>
<p>SoftArtisans WordWriter opens a WordWriter template file, 
	populates it with data from a specified data source, and generates a new Word file.  
	A WordWriter template is a file created in Microsoft Word that contains <b>merge fields</b>.  
	A merge field displays a data source field name (for example, 
	a database column name) where a data source value will be inserted.
	Merge fields are bound to a data source in the WordWriter ASP.NET script. 
	When you run the code, WordWriter populates the data markers with values from 
	the data source and creates a new Word file.</p>
<table>
	<tr>
	<td><div class="indent"><h6>VB.NET Example</h6></div>
	<%
	ShowExample ("Basic/StringVar/StringVar-vb.aspx")
	%>
	<div class="indent">[<a target="_blank" href="<%=vroot%>samples/Basic/StringVar/StringVarTemplate.doc">View Template</a>]</div>
	</td>
	<td><div class="indent"><h6>C# Example</h6></div>
	<%
	ShowExample ("Basic/StringVar/StringVar-cs.aspx")
	%>
	<div class="indent">[<a target="_blank" href="<%=vroot%>samples/Basic/StringVar/StringVarTemplate.doc">View Template</a>]</div>
	</td>
	</tr>
	</table><br>
<hr>
<table cellspacing=5>
<tr>
	<td valign=top width=45%><h4>Step 1: Create a Template</h4> 
	<p>To generate a Word file with WordWriter, first create a template:</p>
	<ol>
	<li>In Microsoft Word, create a new file.</li><br><br>
	<li>From the <b>Insert</b> menu, select <b>Field...</b> to open 
	the Field dialog.<br><br>
	<li>From the <b>Field names</b> list, select <b>MergeField</b>.<br><br>
	<li>In the <b>Field name</b> text box, enter a name for the merge 
	field.  For example, enter <i>ProductName</i>.<br><br>
	<li>Click Ok.  The merge field will be displayed in the document 
		in the format &lt;&lt;Field Name&gt;&gt;.</li><br><br>
	<li>To insert additional merge fields, repeat steps 2-4.</li>
	</ol></td>
	<td><img border=1 src="<%=vroot%>images/simpletemplate.jpg"></td>
</tr>
<tr><td></td>
	<td><b>To add a merge field to a template, select open the Insert 
	menu and select Field.  The merge field display format is &lt;&lt;Field Name&gt;&gt;.
	</b></td>
</tr>
</table>
<p><a href="#top">Top</a></p><hr>
<h4>Step 2: Write the WordWriter Code</h4>
<p>Next, create an ASP.NET script that uses WordWriter to open the template, fill in 
merge field values, and generate a new Word file.  The VB.NET and C# samples 
above generate a file from the template StringVarTemplate.doc 
(included in WordWriter\doc-samples\samples\basic\stringvar).  
This template contains a single merge field - <b>&lt;&lt;Product Name&gt;&gt;</b>.  
The data source for the merge field is a single-element array.</p>
<p>The <code>WordTemplate</code> object represents the template Word file.  
The <code>WordTemplate</code> object is in the SoftArtisans.WordWriter namespace. 
The object can be referenced as  
<code>SoftArtisans.WordWriter.WordTemplate</code>. To minimize typing and errors, use 
an Import directive to import the namespace to the aspx page, and reference 
the object as <code>WordTemplate</code>, without the namespace prefix:</p>
<pre>	<code>&lt;%@ Import Namespace="SoftArtisans.WordWriter" %&gt;</code></pre>
<p>To generate a new Word file with WordWriter:</p>
<ol>
	<li>Create an instance of the <code>WordTemplate</code> object, for example:
	<pre>	<code>'--- Declare the WordTemplate object and 
	'--- intialize it as Nothing.
	Dim oWW As WordTemplate = Nothing
	...	
	'--- Instantiate the WordTemplate object.
	oWW = New WordTemplate()
</code></pre>
	<li>Call <code>WordTemplate.Open</code> to open a template Word file, 
	for example:
	<table>
	<tr>
	<td>
	<pre>	<code>oWW.Open(Server.MapPath("./StringVarTemplate.doc"))</code></pre>
	<p>The <code>Open</code> method takes either the template's path (as in the example) 
	or a System.IO.Stream object (for example, System.IO.FileStream).  </p></td>
	<td><table class=bluenote bgcolor="#E5EEF5" cellpadding=5 bordercolor="005a9b" border=1 cellspacing=0 ID="Table1">
	<tr>
	<td>WordWriter supports Microsoft Word 97, 2000, and 2002 (XP). 
	Do not use <code>Open</code> to open files created in earlier versions of Microsoft Word.</td>
	</tr>
	</table></td>
	</tr>
	</table><br>
	<li>Call <code>WordTemplate.SetDataSource</code> to bind the template's 
	merge fields to a data source, for example:
	<pre>	<code>Dim arrValue As Object() = {"SoftArtisans WordWriter"}
	Dim arrName As String() = {"ProductName"}
	...
	oWW.SetDataSource(arrValue, arrName)</code></pre>
	<p>StringVar-vb.aspx uses a single variable as a data source.  
	To set the data source to a single value, put the value in a single-element 
	object array, and the merge field name in a single-element string array.  Pass the two 
	arrays to <code>WordTemplate.SetDataSource</code>.</p>
	<li><p>Call <code>WordTemplate.Process</code> to enter values from the data source into the 
	template's merge fields:
	<pre><code>	oWW.Process()</code></pre>
	<li><p>Call <code>WordTemplate.Save</code> to save the generated file or stream it to the browser.
	In the samples above the file is streamed to the browser:
	<pre><code>	oWW.Save(Page.Response, "StringVarOutput.doc", False)</code></pre>
	When you pass <code>Save</code> an HttpResponse object (<code>Page.Response</code>) 
	WordWriter will stream the file to the browser.  
	The method's second parameter specifies a 
	default name for the generated file; this name will be displayed in the browser's 
	File Download dialog.  The third parameter specifies whether the file should open in 
	the browser window or in Microsoft Word; if the parameter is set to False, the file 
	will open in Word.</p>
	<p>WordWriter 
also allows you to save the generated file on the server.  For more information, 
see <a href="<%=vroot%>doc/features/writing.asp">Output Options</a>.</p>
</ol>



<p><a href="#top">Top</a></p>

<!-- #include file="../../include/footer.inc" -->
