<!-- #include file="../../include/header.inc" -->
<!-- #include file="ref_link.inc" -->
<table width=95%>
<tr>
<td valign=top><strong><font color="005a9b">ASP.NET Programmer's Reference</font></strong>
<h2>WordTemplate.SetCultureInfo Method</h2></td>
<td align=right valign=top><img src="<%=vroot%>images/wordwriter.gif"></td>
</tr>
</table>
<hr>
<h6>C# Syntax:</h6>
<div class=indent>
<tt>public void WordTemplate.<code><b>SetCultureInfo</b></code>(System.Globalization.CultureInfo cultureInfo);</tt></div>
<h6>VB.NET Syntax:</h6>
<div class=indent>
<tt>Public Sub WordTemplate.<code><b>SetCultureInfo</b></code>(cultureInfo As System.Globalization.CultureInfo)</tt></div>
<h6>Description:</h6>
<div class=indent>
<p>The <code>SetCultureInfo</code> method allows you to override the server's default 
locale when generating a new Word file.  For example, to generate a US English document 
on a French operating system, you could use <code>SetCultureInfo</code> to set the 
Word file's 
<a target=new href="http://msdn.microsoft.com/library/default.asp?url=/library/en-us/cpref/html/frlrfsystemglobalizationcultureinfoclasstopic.asp">
CultureInfo</a><img src="<%=vroot%>images/weblink.gif"> to US English.</p>
</div>
<h6>Parameter:</h6>
<div class=indent>
<p><code>SetCultureInfo</code> takes a System.Globalization.CultureInfo object.  
This object represents information about a culture including its alphabet, calendar, 
and date formats.  </p>
<p>The CultureInfo object is in the System.Globalization namespace. Use an Import 
directive to import this namespace to the aspx page: </p>
<pre><code>	&lt;%@ Import Namespace="System.Globalization" %&gt;</code></pre>
<p>The CultureInfo passed to <code>SetCultureInfo</code> 
must include both language and country (for example "fr-BE" for French-Belgium).
WordWriter will throw an exception if the CultureInfo object 
passed to <code>SetCultureInfo</code> is invariant (an empty string) or 
neutral (for example, "en" rather 
than "en-US" or "en-AU").  </p>
<p>See 
<a target=new href="http://msdn.microsoft.com/library/default.asp?url=/library/en-us/cpref/html/frlrfsystemglobalizationcultureinfoclasstopic.asp">
CultureInfo Class</a><img src="<%=vroot%>images/weblink.gif"> for more information 
about the class, its members, and a list of CultureInfo codes.</p>
</div>
<h6>Exceptions:</h6>
<ul>
	<li><b><a target="new" href="http://msdn.microsoft.com/library/default.asp?url=/library/en-us/cpref/html/frlrfsystemargumentexceptionclasstopic.asp">
	System.ArgumentException</a></b><img src="<%=vroot%>images/weblink.gif"><br></li>
	<code>SetCultureInfo</code> will throw this exception if the CultureInfo object 
	passed to it is invariant (an empty string) or neutral (for example "en" rather 
	than "en-US" or "en-AU").  The CultureInfo passed to <code>SetCultureInfo</code> 
	must include both language and country (for example "fr-BE" for French-Belgium).<br><br>
	<li><b><a target="new" href="http://msdn.microsoft.com/library/default.asp?url=/library/en-us/cpref/html/frlrfSystemSecuritySecurityExceptionClassTopic.asp">
	System.Security.SecurityException</a></b><img src="<%=vroot%>images/weblink.gif"><br>
	If you pass null to <code>SetCultureInfo</code>, WordWriter sets 
	the Word file's CultureInfo to the system's default CultureInfo.  
	If system security denies access to the system's default CultureInfo, 
	<code>SetCultureInfo(null)</code> will throw a SecurityException.</li>
</ul>
<h6>Examples:</h6>
<pre><code>	[VB.NET]
	'--- The CultureInfo class is in the System.Globalization
	'--- namespace.  Import this namespace to the aspx page.
	&lt;%@ Import Namespace="System.Globalization" %&gt;
	
	...
	
	'--- Create an instance of the WordWriter object.
	oWW = New WordTemplate()
	
	'--- Declare a <a target=new href="http://msdn.microsoft.com/library/default.asp?url=/library/en-us/cpref/html/frlrfsystemglobalizationcultureinfoclasstopic.asp">CultureInfo</a><img src="<%=vroot%>images/weblink.gif"> object and set it to 
	'--- US English.	
	Dim enUS As New CultureInfo("en-US", False)
	
	'--- Pass the US English CultureInfo object to the
	'--- SetCultureInfo method.
	oWW.SetCultureInfo(enUS)

	'--- Call Open() to open the template file.
	oWW.Open(Server.MapPath("./FormattingTemplate.doc"))
	
	'--- Set the template's data source.
	oWW.SetDataSource(arrValue, arrName)

	'--- Call Process() to populate the template with 
	'--- the new data.
	oWW.Process()

	'--- After processing the template, call Save() and pass it 
	'--- Page.Response to stream the generated file to the browser.
	oWW.Save(Page.Response, "FormattingOutput.doc", False)</code></pre>
<!-- #include file="ref_link.inc" -->
<!-- #include file="../../include/footer.inc" -->
