<!-- #include file="../../include/header.inc" -->
<!-- #include file="ref_link.inc" -->
<table width=95%>
<tr>
<td valign=top><strong><font color="005a9b">ASP.NET Programmer's Reference</font></strong>
<h2>WordTemplate.SetDataSource Method</h2></td>
<td align=right valign=top><img src="<%=vroot%>images/wordwriter.gif"></td>
</tr>
</table>
<hr>
<table width=100% class=table2 border=1 bordercolor=white>
<tr>
	<td><code><a href="#1darray">SetDataSource(Values as Object Array, Fields as String Array)</a></code><br>
	<div class=indent>
	Sets a template's data source to a one-dimensional array of objects.	
	</div></td>
</tr>
<tr>
	<td><code><a href="#dataset">SetDataSource(DataSet)</a></code><br>
	<div class=indent>
	Sets a template's data source to an ADO.NET DataSet.
	</div></td>
</tr>
<tr>
	<td><code><a href="#datatable">SetDataSource(DataTable)</a></code><br>
	<div class=indent>
	Sets a template's data source to an ADO.NET DataTable.
	</div></td>
</tr>
</table><hr>
<h4><a name="1darray"></a>SetDataSource(Values as Object Array, Fields as String Array)</h4>
<h6>C# Syntax:</h6>
<div class=indent>
<tt>
public int WordTemplate.<code><b>SetDataSource</b></code>(object[] values, string[] names);</tt>
</div>
<h6>VB.NET Syntax:</h6>
<div class=indent>
<tt>
Public Function WordTemplate.<code><b>SetDataSource</b></code>(values As Object(), names As String()) As Integer</tt>
</div>
<h6>Description:</h6>
<div class=indent>
<p>Sets a template's data source to a one-dimensional object array.  This method 
takes an object array of values and a string array of field names.  The two 
arrays must contain the same number of elements.  Each name in the array of field 
names must be the same as the corresponding merge field name in the template.</p>
<p>Each merge field in a WordWriter template must bind to a data source field/value pair. 
The number of merge fields in the template may not exceed the number of values in the 
data source. However, the number of values in the data source may be greater than the 
number merge fields in the template. </p>
<table bgcolor="#E5EEF5" cellpadding=5 bordercolor="005a9b" border=1 cellspacing=0 ID="Table1">
<tr>
<td>In WordWriter 1.0, a template can have only one data source.  Do not 
call <code>SetDataSource</code> more than once for a single instance of <code>WordTemplate</code>.
</td></tr></table></div>
<h6>Parameters:</h6>
<ul>
	<li><tt><b>object[]</b></tt><br>
	An object array of values to use as a data source.  WordWriter 
	will insert these values in the template's merge fields.</li>
	<li><tt><b>string[]</b></tt><br>
	A string array of data source field names.  These must be the same 
	as the corresponding merge field names in the template</li>
</ul>
<h6><a name="Exceptions"></a>Exceptions:</h6>
<ul>
	<li><b><a target="new" href="http://msdn.microsoft.com/library/default.asp?url=/library/en-us/cpref/html/frlrfsystemargumentexceptionclasstopic.asp">
	System.ArgumentException</a></b><img src="<%=vroot%>images/weblink.gif"><br>
	<code>SetDataSource</code> will throw this exception if the object array 
	and field name array passed to the method do not contain the 
	same number of elements.</li>
	<li><b><a target="new" href="http://msdn.microsoft.com/library/default.asp?url=/library/en-us/cpref/html/frlrfsystemargumentexceptionclasstopic.asp">
	System.ArgumentNullException</a></b><img src="<%=vroot%>images/weblink.gif"><br>
	<code>SetDataSource</code> will throw this exception if <tt>null</tt> (C#)
	or <tt>Nothing</tt> (VB.NET) is passed to the method.</li>
</ul>
<h6>Example:</h6>
	<pre><code>	[VB.NET]
	'--- Create a string array of field names. 
	'--- The field names must be the same as the merge field 
	'--- names in the template.
	Dim arrFields As String() =	{"CompanyName", _
			"StreetAddr", _
			"City", _
			"State", _
			"ZipCode"}

	'--- Create an object array of values
	'--- Ordinal numbers match those of the fields array
	Dim arrValues As Object() =	{"SoftArtisans", _
			"1330 Beacon Street", _
			"Brookline", _
			"MA", _
			"02446"}
	
	oWW.SetDataSource(arrValues, arrFields)</code></pre>
<p><a href="#top">Top</a></p><hr>

<h4><a name="dataset"></a>SetDataSource(DataSet)</h4>
<h6>C# Syntax:</h6>
<div class=indent>
<tt>
public int WordTemplate.<code><b>SetDataSource</b></code>(System.Data.DataSet);</tt>
</div>
<h6>VB.NET Syntax:</h6>
<div class=indent>
<tt>
Public Function WordTemplate.<code><b>SetDataSource</b></code>(System.Data.DataSet) As Integer</tt>
</div>
<h6>Description:</h6>
<div class=indent>
<p>Sets a template's data source to an ADO.NET DataSet.  A DataSet contains a collection 
of DataTables. If you set a template's data source to a DataSet, WordWriter will get the 
first row of the first DataTable in the DataSet. </p>
<p>The DataSet object is in the System.Data namespace. Use an 
Import directive to import the namespace to the aspx page: </p>
<pre>	<code>&lt;%@ Import namespace="System.Data" %&gt;</code></pre>
<table bgcolor="#E5EEF5" cellpadding=5 bordercolor="005a9b" border=1 cellspacing=0 ID="Table1">
<tr>
<td>In WordWriter 1.0, a template can have only one data source.  Do not 
call <code>SetDataSource</code> more than once for a single instance of <code>WordTemplate</code>.
</td></tr></table>
</div>
<h6>Parameters:</h6>
<ul>
	<li><tt><b>DataSet</b></tt><br>
	An ADO.NET DataSet to use as the template's data source.  WordWriter will 
	use the first row of the first DataTable in the DataSet as the data source.</li>
</ul>
<h6><a name="Exceptions"></a>Exceptions:</h6>
<ul>
	<li><b><a target="new" href="http://msdn.microsoft.com/library/default.asp?url=/library/en-us/cpref/html/frlrfsystemargumentexceptionclasstopic.asp">
	System.ArgumentNullException</a></b><img src="<%=vroot%>images/weblink.gif"><br>
	<code>SetDataSource</code> will throw this exception if <tt>null</tt> (C#)
	or <tt>Nothing</tt> (VB.NET) is passed to the method.</li>
</ul>
<h6>Example:</h6>
	<pre><code>	[VB.NET]
	Dim oConn As OleDbConnection
	Dim oAdpt As OleDbDataAdapter
	Dim oDS As DataSet
	Dim oWW As WordWriter

	oWW = New WordTemplate()
	oWW.Open(Server.MapPath(Application("vroot").ToString() + _
				"templates/databasetemplate1.doc"))

	Dim strSQL As String = String.Format("SELECT LastName, FirstName, TitleOfCourtesy,_ 
				Address, City, Region, PostalCode " + _
				"FROM Employees WHERE EmployeeID={0}", _
				employeeSelect.SelectedItem.Value.ToString())
		
	'--- Open an OLEDB connection.
	oConn = New OleDbConnection(strConnString)
	oConn.Open()
			
	'--- Create an instance of the OleDbDataAdapter 
	'--- object.
	oAdpt = New OleDbDataAdapter(strSQL, oConn)
		
	'--- Create a DataSet and fill it with the data 
	'--- returned by the SQL database query.	
	oDS = New DataSet()
	oAdpt.Fill(oDS)

	'--- Pass the DataSet to setDataSource.  WordWriter 
	'--- will use the first DataTable in the DataSet as 
	'--- the data source.		
	oWW.SetDataSource(oDS)</code></pre>
<p><a href="#top">Top</a></p><hr>

<h4><a name="datatable"></a>SetDataSource(DataTable)</h4>
<h6>C# Syntax:</h6>
<div class=indent>
<tt>
public int WordTemplate.<code><b>SetDataSource</b></code>(System.Data.DataTable);</tt>
</div>
<h6>VB.NET Syntax:</h6>
<div class=indent>
<tt>
Public Function WordTemplate.<code><b>SetDataSource</b></code>(System.Data.DataTable) As Integer</tt>
</div>
<h6>Description:</h6>
<div class=indent>
<p>Sets a template's data source to an ADO.NET DataTable.  If the specified 
DataTable contains more than one row, WordWriter will use the first row as 
the data source.</p>
<p>The DataTable object is in the System.Data namespace. Use an 
Import directive to import the namespace to the aspx page: </p>
<pre>	<code>&lt;%@ Import namespace="System.Data" %&gt;</code></pre>
<table bgcolor="#E5EEF5" cellpadding=5 bordercolor="005a9b" border=1 cellspacing=0 ID="Table1">
<tr>
<td>In WordWriter 1.0, a template can have only one data source.  Do not 
call <code>SetDataSource</code> more than once for a single instance of <code>WordTemplate</code>.
</td></tr></table>
</div>
<h6>Parameters:</h6>
<ul>
	<li><tt><b>DataTable</b></tt><br>
	An ADO.NET DataTable to use as the data source.
	WordWriter will use the first row of the  
	DataTable as the data source.</li>
</ul>
<h6><a name="Exceptions"></a>Exceptions:</h6>
<ul>
	<li><b><a target="new" href="http://msdn.microsoft.com/library/default.asp?url=/library/en-us/cpref/html/frlrfsystemargumentexceptionclasstopic.asp">
	System.ArgumentNullException</a></b><img src="<%=vroot%>images/weblink.gif"><br>
	<code>SetDataSource</code> will throw this exception if <tt>null</tt> (C#)
	or <tt>Nothing</tt> (VB.NET) is passed to the method.</li>
</ul>
<h6>Example:</h6>
	<pre>	<code>[VB.NET]
	'--- Instantiate and open an OleDbConnection, passing the connection string.
	oConn = New OleDbConnection(strConnString)
	oConn.Open()

	'--- Instantiate an OleDbDataAdapter.
	oAdpt = New OleDbDataAdapter(strSQL, oConn)

	'--- Instantiate and populate DataSet.
	oDS = New DataSet()
	oAdpt.Fill(oDS, "myDataTable")

	'--- Get a DataTable from the DataSet.
	oDT = oDS.Tables("myDataTable")

	'--- Instantiate the WordTemplate object.
	oWW = New WordTemplate()

	'--- Call Open() to open the template file.
	oWW.Open(Server.MapPath("./DataTableTemplate.doc"))

	'--- Pass the DataTable object to SetDataSource().
	oWW.SetDataSource(oDT)
			
	'--- Call Process() to populate the template with the new data.
	oWW.Process()

	oWW.Save(Page.Response, "DataTableOutput.doc", False)
</code></pre>
<p><a href="#top">Top</a></p>
<!-- #include file="ref_link.inc" -->
<!-- #include file="../../include/footer.inc" -->
