<!-- #include file="../../include/header.inc" -->
<!-- #include file="ref_link.inc" -->
<table width=95%>
<tr>
<td valign=top><strong><font color="005a9b">ASP Programmer's Reference</font></strong>
<h2>WordTemplate.SetDataSource Method</h2></td>
<td align=right valign=top><img src="<%=vroot%>images/wordwriter.gif"></td>
</tr>
</table>
<hr>
<table width=100% class=table2 border=1 bordercolor=white>
<tr>
	<td><code><a href="#1darray">SetDataSource(arrValues As Array, arrNames As Array)</a></code><br>
	<div class=indent>
	Sets a template's data source to a one-dimensional array of objects.	
	</div></td>
</tr>
<tr>
	<td><code><a href="#recordset">SetDataSource(RecordSet)</a></code><br>
	<div class=indent>
	Sets a template's data source to an ADO recordset.
	</div></td>
</tr>

</table><hr>
<h4><a name="1darray"></a>SetDataSource(arrValues As Array, arrNames As Array)</h4>
<h6>Syntax:</h6>
<div class=indent>
<tt>
Sub WordTemplate.<code><b>SetDataSource</b></code>(arrValues As Array, arrNames As Array)</tt>
</div>
<h6>Description:</h6>
<div class=indent>
<p>Sets a template's data source to a one-dimensional array.  This method 
takes an array of values and an array of field names.  The two 
arrays must contain the same number of elements.  Each name in the array of field 
names must be the same as the corresponding merge field name in the template.</p>
<p>Each merge field in a WordWriter template must bind to a data source field/value pair. 
The number of merge fields in the template may not exceed the number of values in the 
data source. However, the number of values in the data source may be greater than the 
number merge fields in the template. </p>
<table bgcolor="#E5EEF5" cellpadding=5 bordercolor="005a9b" border=1 cellspacing=0 ID="Table1">
<tr>
<td>In WordWriter 1.0, a template can have only one data source.  Do not 
call <code>SetDataSource</code> more than once for a single instance of <code>WordTemplate</code>.
</td></tr></table></div>
<h6>Parameters:</h6>
<ul>
	<li><tt><b>arrValues</b></tt><br>
	An array of values to use as a data source.  WordWriter 
	will insert these values in the template's merge fields.</li>
	<li><tt><b>arrNames</b></tt><br>
	An array of data source field names.  These must be the same 
	as the corresponding merge field names in the template.</li>
</ul>
<h6>Example:</h6>
<pre><code>	[VB]
	Dim arrValues
	Dim arrNames
	Dim oWW
	
	'--- Create an array of values.  These values will be 
	'--- inserted in the template's merge fields. 
	arrValues = Array("SoftArtisans", "WordWriter", "http://www.softartisans.com")
	
	'--- Create an array of field names.  These must be the 
	'--- same as the corresponding merge field names in the template.
	'--- The array of values and the array of names must contain 
	'--- the same number of elements.
	arrNames = Array("CompanyName", "ProductName", "URL")

	'--- Create an instance of WordTemplate.
	Set oWW = Server.CreateObject("SoftArtisans.WordTemplate")
	
	'--- Call the Open method to open the template file
	oWW.Open(Server.MapPath("./Template.doc"))

	'--- Set the data source of the document by passing
	'--- the value array and the name array that we initialized above.
	oWW.SetDataSource arrValues, arrNames

	'--- Call WordTemplate.Process to populate the template with the 
	'--- new data.
	oWW.Process

	'--- Stream the generated file to the client.
	oWW.Save Response, "ArrayVarsOutput.doc", False 
	
	'--- Clean Up
	Set oWW = Nothing</code></pre>
<p><a href="#top">Top</a></p><hr>

<h4><a name="recordset"></a>SetDataSource(RecordSet)</h4>
<h6>Syntax:</h6>
<div class=indent>
<tt>Sub WordTemplate.<code><b>SetDataSource</b></code>(oRS As RecordSet)</tt>
</div>
<h6>Description:</h6>
<div class=indent>
<p>Sets a template's data source to an ADO recordset.  If the specified 
recordset contains more than one row, WordWriter will use the first row as 
the data source.</p>
<table bgcolor="#E5EEF5" cellpadding=5 bordercolor="005a9b" border=1 cellspacing=0 ID="Table1">
<tr>
<td>In WordWriter 1.0, a template can have only one data source.  Do not 
call <code>SetDataSource</code> more than once for a single instance of <code>WordTemplate</code>.
</td></tr></table>
</div>
<h6>Parameters:</h6>
<ul>
	<li><tt><b>RecordSet</b></tt><br>
	An ADO recordset to use as the data source.
	WordWriter will use the first row of the  
	recordset as the data source.</li>
</ul>
<h6>Example:</h6>
<pre><code>	[VB]
	Dim oConn
	Dim oRS
	Dim strConnString
	Dim oWW
	Dim strSQL

	'--- Set the connection string.
	strConnString = Application("connString")

	'--- SQL statement used to query the database
	strSQL = "SELECT TOP 1 TitleOfCourtesy, FirstName, LastName, Title FROM Employees"
			
	'--- Instantiate and open an ADO Connection, 
	'--- passing the connection string.
	Set oConn = Server.CreateObject("ADODB.Connection")
	oConn.Open strConnString

	'--- Query the database and get a RecordSet.
	Set oRS = oConn.Execute(strSQL)
	
	'--- Instantiate the WordWriter.WordTemplate object.
	Set oWW = Server.CreateObject("SoftArtisans.WordTemplate")

	'--- Call Open() to open the template file
	oWW.Open Server.MapPath("./Template.doc")
	
	'--- Pass the RecordSet object to SetDataSource().
	oWW.SetDataSource oRS
	
	'--- Call WordTemplate.Process() to populate the template 
	'--- with the new data.
	oWW.Process

	'--- Stream the generated Word file to the client.
	oWW.Save Response, "DataTableOutput.doc", False

	'--- Clean up
	oRS.Close
	oConn.Close
	Set oRS = Nothing
	Set oConn = Nothing
	Set oWW = Nothing</code></pre>
<p><a href="#top">Top</a></p>
<!-- #include file="ref_link.inc" -->
<!-- #include file="../../include/footer.inc" -->