using System;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using SoftArtisans.WordWriter;

namespace WordWriterDemos
{
	public abstract class CalendarDemo : System.Web.UI.Page
	{

	  /*
	  *	SoftArtisans WordWriter.Net Calendar Sample (C#)
	  *	------------------------------------------------
	  *
	  *	This sample demonstrates how to create a dynamic, properly
	  *	formatted calendar using WordWriter and a MS Word template.
	  *
	  *	Enter any year and month to generate a calendar.
	  *
	  *	Copyright (c) 2003 SoftArtisans, Inc.
	  *	Mail: info@softartisans.com   http://www.softartisans.com
	  *
	  */

		  //--- Declare items on the webform
		  protected HtmlInputText txtYear = null;
		  protected HtmlSelect lstMonth = null;
		  protected Label lblResult = null;

		  //--- This method runs when the submit button on the web form is clicked
		  protected void btnSubmit_Click(object sender, EventArgs args)
		  {
			  this.lblResult.Text = "";
			  this.FormCalendar();
		  }

		  //--- This method reads the input from the form
		  //--- and forms the name and value array so that the calendar
		  //--- is properly formatted
		  private void FormCalendar()
		  {
			  
			  //--- Declare variables to hold the selected month and year values
			  int month = 0;
			  int year = 0;

			  //--- Read the month and year entered on the web form
			  try
			  {
				  //--- Read the selected month and year from the web form
				  month = Convert.ToInt32(lstMonth.Value);
				  year = Convert.ToInt32(txtYear.Value);
			  }
			  catch(System.Exception ex)
			  {
				  //--- If the Convert.ToInt32() method throws an exception, invalid data was entered
				  this.lblResult.Text = "<B>Error</B><BR>You entered invalid data in the form.  Pleaes check your month and year entries.";
				  return;
			  }


			  //--- Form the name array that will be passed to WordWriter.  The elements
			  //--- of this array are the names of the merge fields in the calendar document
			  string[] arrNames = {"Block1", "Block2", "Block3", "Block4", "Block5", "Block6", "Block7", "Block8", "Block9", "Block10",
							  "Block11", "Block12", "Block13", "Block14", "Block15", "Block16", "Block17", "Block18", "Block19", "Block20",
							  "Block21", "Block22", "Block23", "Block24", "Block25", "Block26", "Block27", "Block28", "Block29", "Block30",
							  "Block31", "Block32", "Block33", "Block34", "Block35", "Block36", "Block37", "Block38", "Block39", "Block40",
							  "Block41", "Block42", "MonthYear"};

			  //--- Declare a DateTime struct that we will use
			  //--- to determine information about the current month
			  //--- such as the number of days in the month, and the 
			  //--- starting day of the week
			  DateTime oDateTime;
			  
			  try
			  {
				  //--- Instantiate the DateTime struct for the first day of
				  //--- the month and year selected
				  oDateTime = new DateTime(year, month, 1);
			  }
			  catch(System.Exception ex)
			  {
				  //--- If the DateTime struct cannot be instantiated, alert the user
				  this.lblResult.Text = "<B>Error</B><BR>Your year/month selections are somehow invalid.<BR>" + ex.Message;
				  return;
			  }
		  
			  //--- Determine on which day of the week the month begins
			  DayOfWeek startday = oDateTime.DayOfWeek;

			  //--- Get the number of days in the selected month
			  int daysinmonth = DateTime.DaysInMonth(year, month);

			  //--- Declare the object array that will be used to hold the 
			  //--- values inserted into the calendar template
			  object[] arrDayBlocks = new object[43];
					  
			  //--- The first date of the month is, as always, 1
			  int dayofmonth = 1;

			  //--- Loop through all of the available blocks in the calendar
			  //--- templaet
			  for(int iDayBlock = 0; iDayBlock <= 41; iDayBlock++)
			  {
				  //--- If the block exists before the first day of the month, enter an empty string
				  //--- If the block exists after the last day of the month, enter an empty string
				  if((iDayBlock < (int)startday) || (dayofmonth > daysinmonth))
					  arrDayBlocks[iDayBlock] = String.Empty;
				  else
				  {
					  //--- Otherwise, it's a valid block, so enter the day of the month
					  arrDayBlocks[iDayBlock] = dayofmonth;
					  dayofmonth++;
				  }
			  }
			  
			  //--- The last element of the value array is reserved for a DateTime struct.
			  //--- Using MergeField date formatting codes, the template merge fields will 
			  //--- display the Month name and 4-digit year in the appropriate places
			  arrDayBlocks[42] = oDateTime;

			  //--- Pass the created name and value arrays to the GenerateCalendarDocument() method
			  this.GenerateCalendarDocument(arrNames, arrDayBlocks);
		  }


		  //--- This method is invoked from the FormCalendar() method
		  //--- and uses WordWriter to open and populate the calendar template
		  private void GenerateCalendarDocument(string[] arrNames, object[] arrValues)
		  {

			  //--- This string is the full path to the template file
			  string strTemplatePath = this.MapPath("./CalendarTemplate.doc");
			  
			  //--- Declare and initialize the WordWriter.WordTemplate reference
			  WordTemplate oWW = null;

  			  //--- Create a CultureInfo object representing English/US
			  System.Globalization.CultureInfo enUS = new System.Globalization.CultureInfo("en-US");	
					
			  try
			  {
				  //--- Instantiate the WordWriter.WordTemplate object
				  oWW = new WordTemplate();

		              //--- Configure WordWriter to use the US/English culture
				  oWW.SetCultureInfo(enUS);

				  //--- Open the template file
				  oWW.Open(strTemplatePath);

				  //--- Set the datasource with the name and value arrays defined above
				  oWW.SetDataSource(arrValues, arrNames);

				  //--- Process the template
				  oWW.Process();

				  //--- Begin streaming the processed document
				  oWW.Save(Page.Response, "CalendarOutput.doc", false);
				  Response.Flush();
				  Response.End();

			  }
			  catch(System.Exception ex)
			  {
				  //--- Catch any exceptions thrown by WordWriter
				  Response.ClearHeaders();
				  lblResult.Text = "<B>Error</B><BR>WordWriter could not process your document.<BR>" + ex.Message;
				  return;
			  }
		  
		  } // end method

	} // end class

} // end namespace