Option Explicit On
Option Strict On

Imports System
Imports System.Web.UI.WebControls
Imports System.Web.UI.HtmlControls
Imports SoftArtisans.WordWriter

Namespace WordWriterDemos

	Public MustInherit Class CalendarDemo : Inherits System.Web.UI.Page

	'
	'	SoftArtisans WordWriter.Net Calendar Sample (VB.NET)
	'	----------------------------------------------------
	'
	'	This sample demonstrates how to create a dynamic, properly
	'	formatted calendar using WordWriter and a MS Word template.
	'
	'	Enter any year and month to generate a calendar.
	'
	'	Copyright (c) 2003 SoftArtisans, Inc.
	'	Mail: info@softartisans.com   http://www.softartisans.com
	'
		'--- Declare items on the webform
		Protected txtYear As HtmlInputText = Nothing
		Protected lstMonth As HtmlSelect = Nothing
		Protected lblResult As Label = Nothing 

		'--- This method runs when the submit button on the web form is clicked
		Protected Sub btnSubmit_Click(sender As Object, args As EventArgs)
		
			Me.lblResult.Text = ""
			Me.FormCalendar()
		
		End Sub

		'--- This method reads the input from the form
		'--- and forms the name and value array so that the calendar
		'--- is properly formatted
		Private Sub FormCalendar()
		
			'--- Declare variables to hold the selected month and year values
			Dim month As Integer = 0
			Dim year As Integer = 0

			'--- Read the month and year entered on the web form
			Try
			
				'--- Read the selected month and year from the web form
				month = Convert.ToInt32(Me.lstMonth.Value)
				year = Convert.ToInt32(Me.txtYear.Value)
			
			Catch ex As System.Exception
			
				'--- If the Convert.ToInt32() method throws an exception, invalid data was entered
				Me.lblResult.Text = "<B>Error</B><BR>You entered invalid data in the form.  Pleaes check your month and year entries."
				Return
			
			End Try


			'--- Form the name array that will be passed to WordWriter.  The elements
			'--- of this array are the names of the merge fields in the calendar document
			Dim arrNames() As String = {"Block1", "Block2", "Block3", "Block4", "Block5", "Block6", "Block7", "Block8", "Block9", "Block10", _
							"Block11", "Block12", "Block13", "Block14", "Block15", "Block16", "Block17", "Block18", "Block19", "Block20", _
							"Block21", "Block22", "Block23", "Block24", "Block25", "Block26", "Block27", "Block28", "Block29", "Block30", _
							"Block31", "Block32", "Block33", "Block34", "Block35", "Block36", "Block37", "Block38", "Block39", "Block40", _
							"Block41", "Block42", "MonthYear"}

			'--- Declare a DateTime struct that we will use
			'--- to determine information about the current month
			'--- such as the number of days in the month, and the 
			'--- starting day of the week
			Dim oDateTime As DateTime
			
			Try
			
				'--- Instantiate the DateTime struct for the first day of
				'--- the month and year selected
				oDateTime = New DateTime(year, month, 1)
			
			Catch ex As System.Exception
			
				'--- If the DateTime struct cannot be instantiated, alert the user
				Me.lblResult.Text = "<B>Error</B><BR>Your year/month selections are somehow invalid.<BR>" + ex.Message
				Return

			End Try
		
			'--- Determine on which day of the week the month begins
			Dim startday As DayOfWeek = oDateTime.DayOfWeek

			'--- Get the number of days in the selected month
			Dim daysinmonth As Integer = DateTime.DaysInMonth(year, month)

			'--- Declare the object array that will be used to hold the 
			'--- values inserted into the calendar template
			Dim arrDayBlocks(42) As Object
					
			'--- The first date of the month is, as always, 1
			Dim dayofmonth As Integer = 1

			'--- Loop through all of the available blocks in the calendar
			'--- template
			Dim iDayBlock As Integer = 0
			
			For iDayBlock = 0 To 41 Step 1
			
				'--- If the block exists before the first day of the month, enter an empty String
				'--- If the block exists after the last day of the month, enter an empty String
				If (iDayBlock < CInt(startday)) Or (dayofmonth > daysinmonth) Then
					arrDayBlocks(iDayBlock) = String.Empty
				Else
					'--- Otherwise, it's a valid block, so enter the day of the month
					arrDayBlocks(iDayBlock) = dayofmonth
					dayofmonth += 1
				End If

			Next iDayBlock
			
			'--- The last element of the value array is reserved for a DateTime struct.
			'--- Using MergeField date formatting codes, the template merge fields will 
			'--- display the Month name and 4-digit year in the appropriate places
			arrDayBlocks(42) = oDateTime

			'--- Pass the created name and value arrays to the GenerateCalendarDocument() method
			Me.GenerateCalendarDocument(arrDayBlocks, arrNames)
		
		End Sub


		'--- This method is invoked from the FormCalendar() method
		'--- and uses WordWriter to open and populate the calendar template
		Private Sub GenerateCalendarDocument(arrValues As Object(), arrNames As String())
		

			'--- This String is the full path to the template file
			Dim strTemplatePath As String = Server.MapPath("./CalendarTemplate.doc")
			
			'--- Declare and initialize the WordWriter.WordTemplate reference
			Dim oWW As WordTemplate = Nothing

			'--- Create a CultureInfo object representing English/US
			Dim enUS As New System.Globalization.CultureInfo("en-US")

			Try
			
				'--- Instantiate the WordWriter.WordTemplate object
				oWW = New WordTemplate()

				'--- Configure WordWriter to use the US/English culture
				oWW.SetCultureInfo(enUS)
			
				'--- Open the template file
				oWW.Open(strTemplatePath)
			
				'--- Set the datasource with the name and value arrays defined above
				oWW.SetDataSource(arrValues, arrNames)
			
				'--- Process the template
				 oWW.Process()

				'--- Begin streaming the processed document
				oWW.Save(Page.Response, "CalendarOutput.doc", False)
				Response.Flush()
				Response.End()
			
			Catch ex As System.Exception
			
				'--- Catch any exceptions thrown by WordWriter
				Response.ClearHeaders()
				lblResult.Text = "<B>Error</B><BR>WordWriter could not process your document.<BR>" + ex.Message
				Return
			
			End Try
		
		End Sub

	End Class

End Namespace