using System;
using System.Data.OleDb;
using System.Data;
using System.Web.UI.WebControls;
using System.Collections;

/* 
*	SoftArtisans WordWriter.Net MailMerge Sample (C#)
*	-------------------------------------------------
*
*	This sample illustrates how WordWriter is called within 
*	a loop in order to generate multiple form letter documents
*	each with unique recipient information.
*
*	Copyright (c) 2003 SoftArtisans, Inc.
*	Mail: info@softartisans.com   http://www.softartisans.com
*/


using SoftArtisans.WordWriter;

namespace WordWriterDemos
{

	  public abstract class MailMergeForm : System.Web.UI.Page
	  {

		  //--- Declare some class-level variables
		  private string strConnString = String.Empty;
		  protected DataGrid recipientGrid;
		  protected System.Web.UI.HtmlControls.HtmlInputButton btnSubmit;
		  protected Label lblResult;

		  //--- Page_Load() fires when the webform loads.
		  protected void Page_Load(Object sender, EventArgs e)
		  {
			  //--- Connection string to our Northwind database
			  strConnString = "Provider=Microsoft.Jet.OLEDB.4.0;Data source=" +
							Server.MapPath("../../Database/northwind.mdb");

			  //--- If this is the first load of the page, populate the data grid
			  if(!Page.IsPostBack)
				  this.PopulateDataGrid();
		  }

		  //--- Fires when the submit button is clicked
		  protected void btnSubmit_Click(object o, System.EventArgs args)
		  {
			  this.CreateDocuments(this.GetCheckedRecipients());
		  }

		  //--- Populates the main data grid on the webform page.
		  private void PopulateDataGrid()
		  {
			  
			  //--- This SQL query gets a list of employee names and IDs that we'll use to populate the dropdown
			  string strSQL = "SELECT EmployeeID, FirstName, LastName FROM Employees ORDER BY LastName";

			  //--- Declare OleDB objects
			  OleDbConnection oConn = null;
			  OleDbCommand oCmd = null;
			  
			  try
			  {
				  //--- Instantiate and open an OleDbConnection
				  oConn = new OleDbConnection(strConnString);
				  oConn.Open();

				  //--- Instantiate an OleDbCommand object to handle the query
				  oCmd = new OleDbCommand(strSQL, oConn);

				  //--- Execute the query and bind the dropdown's datasource
				  recipientGrid.DataSource = oCmd.ExecuteReader();
				  recipientGrid.DataBind();
			  
			  }
			  catch(System.Exception ex)
			  {
				  this.lblResult.Text = "<b>An error has occurred:</b> " + ex.ToString();
				  return;
			  }
			  finally
			  {
				  //--- Close OleDb database objects
				  if(oConn!=null)
				  {
					  oConn.Close();
					  oConn.Dispose();
				  }

				  if(oCmd!=null)
					  oCmd.Dispose();
			  }
		  }
		  
		  /// <summary>Returns an ArrayList representing the checked items on the main data grid.</summary>
		  /// <returns>An ArrayList representing the checked items on the main grid.</returns>
		  private ArrayList GetCheckedRecipients()
		  {
			  CheckBox chkMailTo = null;
			  ArrayList arrRecipientIDs = new ArrayList();

			  //--- Loop through the checkbox column and see which ones were checked
			  //--- Add the EmployeeIDs of checked boxes into an ArrayList
			  foreach(DataGridItem oDataGridItem in recipientGrid.Items)	
			  {
				  chkMailTo = (CheckBox)oDataGridItem.FindControl("chkMailTo");
				  if(chkMailTo.Checked)
					  arrRecipientIDs.Add(((TableCell)oDataGridItem.Cells[1]).Text.ToString());
			  }

			  return arrRecipientIDs;	
		  }
		  
		  /// <summary>Invokes WordWriter to create documents to all selected recipientd.</summary>
		  /// <returns>void</returns>
		  /// <param name="arrRecipients">An ArrayList containing EmployeeIDs of all intended recipients.</param>
		  private void CreateDocuments(ArrayList arrRecipients)
		  {
			  //--- If the user selected no recipients, tell them so and exit the method
			  if(arrRecipients.Count == 0)
			  {
				  lblResult.Text = "Please select at least one recipient.";
				  return;
			  }

			  //--- Form the SQL query string that we will use to get recipient information from the database
			  string strSQL = String.Format("SELECT LastName, FirstName, TitleOfCourtesy, Address, City, Region, PostalCode " +
									  "FROM Employees WHERE EmployeeID IN ({0})", 
									  /* This joins the ArrayList of EmployeeIDs into a comma-separated string */
									  string.Join(",", (string[])arrRecipients.ToArray(typeof(string))));
			  
			  //--- Declare some objects
			  OleDbConnection oConn = null;
			  OleDbDataAdapter oAdpt = null;
			  DataTable oDT = null;
			  WordTemplate oWW = null;

			  try
			  {
				  //--- Instantiate and open an OleDbConnection
				  oConn = new OleDbConnection(strConnString);
				  oConn.Open();

				  //--- Instantiate an OleDbAdapter
				  oAdpt = new OleDbDataAdapter(strSQL, oConn);

				  //--- Instantiate and fill a DataTable
				  oDT = new DataTable();
				  oAdpt.Fill(oDT);
			  }
			  catch(System.Exception ex)
			  {
				  this.lblResult.Text = "Error: An error occurred when querying the database.<BR>" + ex.ToString();
				  return;
			  }
			  finally
			  {		
				  //--- Clean up OleDb objects
				  if(oConn != null)
				  {
					  oConn.Close();
					  oConn.Dispose();
				  }

				  if(oAdpt != null)
					  oAdpt.Dispose();
			  }

			  //--- Define a list of field marker names we will be replacing in the Word document
			  string[] arrFieldNames = {"TitleOfCourtesy", "FirstName", "LastName", "Address", "City", "Region", "PostalCode"};
			  
			  //--- Define the object array that will hold our values
			  //--- we'll populate the array in the foreach loop below
			  object[] arrValues = new object[7];
			  int count = 0;

			  System.Text.StringBuilder oSB = new System.Text.StringBuilder("Successfully generated documents for:<BR><OL>");
			  
			  try
			  {
				    //--- Instantiate SoftArtisans WordWriter
				    oWW = new WordTemplate();
				  
				    //--- Open the template Word document
				    oWW.Open(this.MapPath("./mergeTemplate.doc"));

				    //--- Set the datasource with the two arrays we created
				    oWW.SetDataSource(arrValues, arrFieldNames);

				    //--- Loop through each recipient in the DataTable
				    foreach(DataRow oDR in oDT.Rows)
				    {			
					//--- Copy the values to an array that we can pass to WordWriter
					arrValues[0] = oDR["TitleOfCourtesy"].ToString();
					arrValues[1] = oDR["FirstName"].ToString();
					arrValues[2] = oDR["LastName"].ToString();
					arrValues[3] = oDR["Address"].ToString();
					arrValues[4] = oDR["City"].ToString();
					arrValues[5] = oDR["Region"].ToString();
					arrValues[6] = oDR["PostalCode"].ToString();

					//--- Populate the template and save it to the disk
					oWW.Process();
					oWW.Save(this.MapPath(String.Format("./MergedDocument-{0}.doc", (++count).ToString())));
					oSB.Append(String.Format("<LI><A HREF=\"MergedDocument-{0}.doc\">{1} {2}</A>", count.ToString(), arrValues[1].ToString(), arrValues[2].ToString()));
				    }
				
			  }
			 
			  catch(System.Exception ex)
			  {
				  //--- Catch any exceptions thrown by WordWriter
				  Response.ClearHeaders();
				  lblResult.Text = "<B>Error</B><BR>WordWriter could not process your document.<BR>" + ex.Message;
				  return;
			  }
			
			  //--- Show the results
			  lblResult.Text = oSB.ToString();

		  }

		  

	  }



}