Option Explicit On
Option Strict On

Imports System
Imports System.Data.OleDb
Imports System.Data
Imports System.Web.UI.WebControls
Imports System.Collections
'--- Import WordWriter namespace
Imports SoftArtisans.WordWriter

' 
'	SoftArtisans WordWriter.Net MailMerge Sample (VB.NET)
'	-----------------------------------------------------
'
'	This sample illustrates how WordWriter is called within 
'	a loop in order to generate multiple form letter documents
'	each with unique recipient information.
'
'	Copyright (c) 2003 SoftArtisans, Inc.
'	Mail: info@softartisans.com   http://www.softartisans.com
'


Namespace WordWriterDemos

	Public MustInherit Class MailMergeForm : Inherits System.Web.UI.Page


		'--- Declare some class-level variables
		Private strConnString As String = String.Empty
		Protected recipientGrid As DataGrid 
		Protected btnSubmit As System.Web.UI.HtmlControls.HtmlInputButton
		Protected lblResult As Label

		'---
		'--- Event that fires when the webform is loaded
		'---
		Protected Sub Page_Load(sender As Object, e As EventArgs)
		
			'--- Connection string to our Northwind database
			strConnString = "Provider=Microsoft.Jet.OLEDB.4.0;Data source=" + _
							Server.MapPath("../../Database/northwind.mdb")

			'--- If this is the first load of the page, populate the drop down
			If (Not Page.IsPostBack) Then
				Me.PopulateDataGrid()
			End If
		End Sub

		'---
		'--- Event that fires when the submit button is clicked
		'---
		Protected Sub btnSubmit_Click(sender As Object, e As EventArgs)
			
			Me.CreateDocuments(Me.GetCheckedRecipients())
		
		End Sub

		'---
		'--- void PopulateDataGrid() populates the data grid with a list
		'--- of available recipients
		'---
		Private Sub PopulateDataGrid()
		
			
			'--- This SQL query gets a list of employee names and IDs that we'll use to populate the dropdown
			Dim strSQL As String = "SELECT EmployeeID, FirstName, LastName FROM Employees ORDER BY LastName"

			'--- Declare OleDB objects
			Dim oConn As OleDbConnection = Nothing
			Dim oCmd As OleDbCommand = Nothing
			
			Try
			
				'--- Instantiate and open an OleDbConnection
				oConn = New OleDbConnection(strConnString)
				oConn.Open()

				'--- Instantiate an OleDbCommand object to handle the query
				oCmd = New OleDbCommand(strSQL, oConn)

				'--- Execute the query and bind the dropdown's datasource
				recipientGrid.DataSource = oCmd.ExecuteReader()
				recipientGrid.DataBind()
			
			Catch ex As System.Exception 
			
				Me.lblResult.Text = "<b>An error has occurred:</b> " + ex.ToString()
				Return

			Finally
				'--- Close OleDb database objects
				If Not (oConn Is Nothing) Then
					oConn.Close()
					oConn.Dispose()
				End If

				If Not (oCmd Is Nothing) Then
					oCmd.Dispose()
				End If
			End Try
		End Sub
		
		'---
		'--- GetCheckedRequests() reads the datagrid
		'--- to determine which recipients are selected
		'---
		Private Function GetCheckedRecipients() As ArrayList 

			Dim chkMailTo As CheckBox
			Dim arrRecipientIDs As New ArrayList
			Dim oDataGridItem As DataGridItem
			'--- Loop through the checkbox column and see which ones were checked
			'--- Add the EmployeeIDs of checked boxes into an ArrayList
			
			For Each oDataGridItem In recipientGrid.Items	
				chkMailTo = CType(oDataGridItem.FindControl("chkMailTo"), CheckBox)
				If(chkMailTo.Checked) Then
					arrRecipientIDs.Add(CType(oDataGridItem.Cells(1), TableCell).Text.ToString())
				End If
			Next oDataGridItem

			Return arrRecipientIDs
		End Function
		
		'---
		'--- void CreateDocuments(System.Collections.ArrayList) 
		'--- queries the database for extended recipient information and 
		'--- uses SoftArtisans WordWriter to generate multiple documents
		'---
		Private Sub CreateDocuments(arrRecipients As ArrayList)
		
			'--- If the user selected no recipients, tell them so and exit the method
			If (arrRecipients.Count = 0) Then
				lblResult.Text = "Please select at least one recipient."
				Return
			End If

			'--- Form the SQL query string that we will use to get recipient information from the database
			Dim strSQL As string = String.Format("SELECT LastName, FirstName, TitleOfCourtesy, Address, City, Region, PostalCode " + _
									"FROM Employees WHERE EmployeeID IN ({0})", _
									String.Join(",", CType(arrRecipients.ToArray(GetType(String)), String())))
											
			'--- Declare some objects
			Dim oConn As OleDbConnection = Nothing
			Dim oAdpt As OleDbDataAdapter = Nothing
			Dim oDT As DataTable = Nothing
			Dim oWW As WordTemplate = Nothing

			Try
			
				'--- Instantiate and open an OleDbConnection
				oConn = New OleDbConnection(strConnString)
				oConn.Open()

				'--- Instantiate an OleDbAdapter
				oAdpt = New OleDbDataAdapter(strSQL, oConn)

				'--- Instantiate and fill a DataTable
				oDT = New DataTable()
				oAdpt.Fill(oDT)
			
			Catch ex As System.Exception 
			
				Me.lblResult.Text = "Error: An error occurred when querying the database.<BR>" + ex.ToString()
				Return
			
			Finally
				'--- Close OleDb database objects
				If Not (oConn Is Nothing) Then
					oConn.Close()
					oConn.Dispose()
				End If

				If Not (oAdpt Is Nothing) Then
					oAdpt.Dispose()
				End If
			End Try

			'--- Define a list of field marker names we will be replacing in the Word document
			Dim arrFieldNames As String() = {"TitleOfCourtesy", "FirstName", "LastName", "Address", "City", "Region", "PostalCode"}
			
			'--- Define the object array that will hold our values
			'--- we'll populate the array in the foreach loop below
			Dim arrValues(6) As Object

			Dim count As Integer = 0
			
			Dim oSB As New System.Text.StringBuilder("Successfully generated documents for:<BR><OL>")

			Try
			
				'--- Instantiate SoftArtisans WordWriter
				oWW = New WordTemplate()
					
				'--- Set the datasource with the two arrays we created
				oWW.SetDataSource(arrValues, arrFieldNames)
			
				'--- Open the template Word document
				oWW.Open(Me.MapPath("./mergeTemplate.doc"))

				
				Dim oDR As DataRow
				'--- Loop through each recipient in the DataTable
				For Each oDR In oDT.Rows
				
					'--- Copy the values to an array that we can pass to WordWriter
					arrValues(0) = oDR.Item("TitleOfCourtesy").ToString()
					arrValues(1) = oDR.Item("FirstName").ToString()
					arrValues(2) = oDR.Item("LastName").ToString()
					arrValues(3) = oDR.Item("Address").ToString()
					arrValues(4) = oDR.Item("City").ToString()
					arrValues(5) = oDR.Item("Region").ToString()
					arrValues(6) = oDR.Item("PostalCode").ToString()

					'--- Populate the template and save it to the disk
					count += 1
					oWW.Process()
					oWW.Save(Me.MapPath(String.Format("./MergedDocument-{0}.doc", count.ToString())))
					oSB.Append(String.Format("<LI><A HREF=""MergedDocument-{0}.doc"">{1} {2}</A>", count.ToString(), arrValues(1).ToString(), arrValues(2).ToString()))
					

				Next oDR

			Catch ex As System.Exception
					
				'--- Catch any exceptions thrown by WordWriter
				Response.ClearHeaders()
				lblResult.Text = "<B>Error</B><BR>WordWriter could not process your document.<BR>" + ex.Message
				Return

			End Try

			
			'--- Show the results
			lblResult.Text = oSB.ToString()

		End Sub

		

	End Class

End Namespace



