<%@ Page Language="C#" Debug="True" %>
<%@ Import Namespace="SoftArtisans.WordWriter" %>
<%@ Import Namespace="System.IO" %>

<script runat="server">
/*
*	SoftArtisans WordWriter.NET StreamIO Sample (C#)
*	-------------------------------------------------
*
*	Both the WordWriter.Open() and WordWriter.Save() methods
*	can take System.IO.Stream objects as arguments.
*	
*	You can open a file with a Stream object and pass
*	it to those methods instead of just string file paths
*
*	Copyright (c) 2003 SoftArtisans, Inc.
*	Mail: info@softartisans.com   http://www.softartisans.com
*
*/

	public void Page_Load(object sender, EventArgs args)
	{
	
		//--- The array of values should be of type object[]
		//--- these values are what will be populated into mergefields in the 
		//--- template document
		object[] arrValue = {"SoftArtisans", "WordWriter", "http://www.softartisans.com"};
		
		//--- The array of names should be of type string[]
		//--- the array indices of the name array should correspond
		//--- to the indices of the value array
		string[] arrName = {"CompanyName", "ProductName", "URL"};


		//--- Declare and initialize some objects
		WordTemplate oWW = null;
		FileStream oTemplateFileStream = null;
		FileStream oOutputFileStream = null;
		
		try
		{
			
			//--- Open both the input file and output file as FileStream objects
			oTemplateFileStream = new FileStream(Server.MapPath("./StreamIOTemplate.doc"), FileMode.Open);
			oOutputFileStream = new FileStream(Server.MapPath("./StreamIOOutput.doc"), FileMode.Create);

			//--- Instantiate WordWriter.WordTemplate
			oWW = new WordTemplate();

			//--- Pass the FileStream for the template file to Open()
			oWW.Open(oTemplateFileStream);

			//--- Set the data source of the document by passing
			//--- the value array and the name array that we initialized above
			oWW.SetDataSource(arrValue, arrName);

			//--- Call WordTemplate.Process() to populate the template with the new data
			oWW.Process();

			//--- Pass the FileStream for the output file to WordTemplate.Save()
			oWW.Save(oOutputFileStream);
					
		}
		catch(System.IO.FileNotFoundException ex)
		{
			//--- If an exception is caught, display a message to the user
			lblResult.Text = "Your template file or output directory cannot be found: " + ex.Message.ToString();
			return;
		}
		catch(System.Exception ex)
		{
			lblResult.Text = "An exception has occurred: " + ex.Message.ToString();
		}
		finally
		{			
			//--- Close all FileStream objects explicitly
			if(oTemplateFileStream != null)
				oTemplateFileStream.Close();

			if(oOutputFileStream != null)
				oOutputFileStream.Close();
		}
		
		//--- If successful, display a message to the user
		lblResult.Text = @"Your document was successfully saved as " + Server.MapPath("./StreamIOOutput.doc");
	}



</script>
<html>
<head>
<title>SoftArtisans WordWriter</title>
</head>
<body>
<img src="../../images/wordwriter.jpg" alt="SoftArtisans WordWriter">
<BR><BR>
<div align="center">
<asp:label runat="server" visible="true" id="lblResult" />
</div>
</body>
</html>