<%@ Page Language="C#" Debug="True" EnableSessionState="False" %>
<%@ Import Namespace="System.Data.OleDb" %>
<%@ Import Namespace="System.Data" %>
<%@ Import Namespace="SoftArtisans.WordWriter" %>

<script runat="server">
/*
*	SoftArtisans WordWriter.NET DatabaseSelect Sample (C#)
*	------------------------------------------------------
*
*	This sample demonstrates how to use WordWriter.NET to create
*	a dynamic form letter with recipient information from a database.
*
*	All letter recipient and author information is dynamically obtained
*	from the web form, and populated into the template document by
*	WordWriter.
*/

	//--- This will be our OleDb connection string
	private string strConnString = String.Empty;


	//--- This method runs when the page loads
	private void Page_Load(Object sender, EventArgs args)
	{
		
		//--- Set the database connection string
		strConnString = "Provider=Microsoft.Jet.OLEDB.4.0;Data source=" +
							Server.MapPath("../../Database/northwind.mdb");

		//--- If the request is not a post-back, populate the data grid
		if(!Page.IsPostBack)
			this.PopulateGrid();
	}
	
	//--- This method is invoked when any of the mail buttons are clicked
	private void Grid_MailTo(Object sender, DataGridCommandEventArgs e)
	{
		//--- Get the employee ID of the clicked row from the data grid
		string employeeID = ((TableCell)e.Item.Cells[1]).Text;
		
		//--- Call the CreateLetter method, passing the employee ID
		this.CreateLetter(employeeID);
	}

	//--- This method populates the data grid on the main page
	private void PopulateGrid()
	{
		//--- Declare OleDb objects
		OleDbConnection oConn = null;
		OleDbCommand oCmd = null;

		//--- SQL statement
		string strSQL = @"SELECT TOP 20 EmployeeID, FirstName, LastName FROM Employees";

		try
		{
			//--- Instantiate and open an OleDbConnection
			oConn = new OleDbConnection(strConnString);
			oConn.Open();

			//--- Instantiate an OleDbCommand
			oCmd = new OleDbCommand(strSQL, oConn);

			//--- Bind the data grid to a data reader object, returned
			//--- from the OleDbCommand object
			this.recipientGrid.DataSource = oCmd.ExecuteReader();
			this.recipientGrid.DataBind();
		
		}
		catch(System.Exception ex)
		{
			//--- If there was an exception, alert the user and stop
			this.lblResult.Text = "<B>Error</B><BR>A database exception has occurred.<BR>" + ex.Message;
			return;
		}
		finally
		{
			//--- Close the database connection
			if(oConn != null)
				oConn.Close();
		}


	}
	
	//--- This method uses WordWriter to create a form letter
	//--- for the requested employeeID
	private void CreateLetter(string employeeID)	
	{
		//--- Declare some object references
		OleDbConnection oConn = null;
		OleDbCommand oCmd = null;
		OleDbDataAdapter oAdpt = null;
		DataSet oDS = null;
		//--- SoftArtisans WordWriter.WordTemplate
		WordTemplate oWW = null;

		//--- This will be the first and last name of the selected recipient
		string strFirstName = String.Empty;
		string strLastName = String.Empty;
		
		//--- The path to our template file
		string strTemplatePath = Server.MapPath("./DatabaseSelectTemplate.doc");
		
		//--- SQL statement used to retrieve employee address information from the database
		string strSQL = "SELECT FirstName, LastName, TitleOfCourtesy, Address, City, Region, PostalCode " +
						"FROM Employees WHERE EmployeeID=?";

		try
		{
			//--- Instantiate and open an OleDbConnection
			oConn = new OleDbConnection(strConnString);
			oConn.Open();

			//--- Instantiate an OleDbCommand and add the employeeID parameter
			oCmd = new OleDbCommand(strSQL, oConn);
			oCmd.Parameters.Add("EmployeeID", employeeID);

			//--- Instantiate an OleDbDataAdapter and fill the dataset
			oAdpt = new OleDbDataAdapter(oCmd);
			oDS = new DataSet();
			oAdpt.Fill(oDS, "employeeIable");
		
			//--- Pull the firstname and lastname from the dataset, we'll use these variables later
			strFirstName = oDS.Tables[0].Rows[0]["FirstName"].ToString();
			strLastName = oDS.Tables[0].Rows[0]["LastName"].ToString();
			
		}
		catch(System.Exception ex)
		{
			//--- If an exception was thrown, alert the user and stop
			lblResult.Text = "<B>Error</B><BR>A database exception has occurred.<BR>" + ex.Message;
			return;
		}
		finally
		{
			//--- Close the database connection
			if(oConn != null)
				oConn.Close();
		}
		
		try
		{
			//--- Instantiate the WordWriter.WordTemplate object
			oWW = new WordTemplate();

			//--- Open the template file
			oWW.Open(strTemplatePath);
			
			//--- Set the datasource with the DataSet containing the recipient information
			oWW.SetDataSource(oDS);
			
			//--- Process the template
			oWW.Process();

			//--- Begin streaming the processed template
			oWW.Save(Page.Response, String.Format("{0}{1}.doc", strLastName, strFirstName), false);
			Response.Flush();
			Response.End();
		
		}
		catch(System.Exception ex)
		{
			//--- Catch any exceptions thrown by WordWriter
			Response.ClearHeaders();
			lblResult.Text = "<B>Error</B><BR>WordWriter could not process your document.<BR>" + ex.Message;
			return;
		}
		
		
	}

</script>

<html>
<head>
<title>SoftArtisans WordWriter</title>
</head>
<body>
<IMG SRC="../../images/wordwriter.jpg" alt="SoftArtisans.WordWriter">
<BR><BR>
<H2><FONT FACE="Arial">Database Letter Sample</FONT></H2>
Select the which recipient from the Northwind Employees table you would like to address a letter to:
<form runat="server">
<asp:DataGrid 
runat="server" 
id="recipientGrid" 
AutoGenerateColumns="False"
BackColor="#e6e6e6" 
Width="300"
HorizontalAlign="Center"
OnItemCommand="Grid_MailTo"
Font-Name="Verdana" 
CellPadding="4"
Font-Size="11pt">
	<HeaderStyle Wrap="False" BackColor="#005a9b" ForeColor="#FFFFFF" Font-Bold="True" HorizontalAlign="Center" />
     <AlternatingItemStyle BackColor="White" /> 

	<Columns>
		<asp:ButtonColumn 
                      
				   HeaderText="Mail to Recipient" 
                       ButtonType="PushButton" 
                       Text="Go" 
                       CommandName="GenerateLetter">
				   <ItemStyle HorizontalAlign="Center" />
		</asp:ButtonColumn>


		<asp:BoundColumn DataField="EmployeeID" visible="False" ReadOnly="True" /> 
		<asp:BoundColumn DataField="LastName" visible="True" HeaderText="Last Name" ReadOnly="True" /> 
		<asp:BoundColumn DataField="FirstName" HeaderText="First Name" ReadOnly="True" /> 
	</Columns>
</asp:DataGrid>
</form>
<div align="center">
<asp:label visible="true" style="color:red" runat="server" id="lblResult" />
</div>
</body>
</html>