<%@ Page Language="VB" Explicit="True" Strict="True" Debug="True" EnableSessionState="False" %>
<%@ Import Namespace="System.Data.OleDb" %>
<%@ Import Namespace="System.Data" %>
<%@ Import Namespace="SoftArtisans.WordWriter" %>

<script runat="server">
'
'	SoftArtisans WordWriter.NET DatabaseSelect Sample (VB.NET)
'	----------------------------------------------------------
'
'	This sample demonstrates how to use WordWriter.NET to create
'	a dynamic form letter with recipient information from a database.
'
'	All letter recipient and author information is dynamically obtained
'	from the web form, and populated into the template document by
'	WordWriter.
'

	'--- This will be our OleDb connection string
	Private strConnString As String = String.Empty


	'--- This method runs when the page loads
	Private Sub Page_Load(sender As Object, args As EventArgs)
			
		'--- Set the database connection string
		strConnString = "Provider=Microsoft.Jet.OLEDB.4.0;Data source=" + _
							Server.MapPath("../../Database/northwind.mdb")

		'--- If the request is not a post-back, populate the data grid
		If Not Page.IsPostBack Then
			Me.PopulateGrid()
		End If
	
	End Sub
	
	'--- This method is invoked when any of the mail buttons are clicked
	Private Sub Grid_MailTo(sender As Object, e As DataGridCommandEventArgs)
	
		'--- Get the employee ID of the clicked row from the data grid
		Dim employeeID As String = CType(e.Item.Cells(1), TableCell).Text
		
		'--- Call the CreateLetter method, passing the employee ID
		Me.CreateLetter(employeeID)
	
	End Sub

	'--- This method populates the data grid on the main page
	Private Sub PopulateGrid()
	
		'--- Declare OleDb objects
		Dim oConn As OleDbConnection = Nothing
		Dim oCmd As OleDbCommand = Nothing

		'--- SQL statement
		Dim strSQL As String = "SELECT TOP 20 EmployeeID, FirstName, LastName FROM Employees"

		Try
		
			'--- Instantiate and open an OleDbConnection
			oConn = New OleDbConnection(strConnString)
			oConn.Open()

			'--- Instantiate an OleDbCommand
			oCmd = New OleDbCommand(strSQL, oConn)

			'--- Bind the data grid to a data reader object, returned
			'--- from the OleDbCommand object
			Me.recipientGrid.DataSource = oCmd.ExecuteReader()
			Me.recipientGrid.DataBind()
		
		Catch ex As System.Exception
		
			'--- If there was an exception, alert the user and stop
			Me.lblResult.Text = "<B>Error</B><BR>A database exception has occurred.<BR>" + ex.Message
			Return
		
		Finally
		
			'--- Close the database connection
			If Not (oConn Is Nothing) Then
				oConn.Close()
			End If
		
		End Try


	End Sub
	
	'--- This method uses WordWriter to create a form letter
	'--- for the requested employeeID
	Private Sub CreateLetter(employeeID As String)	
	
		'--- Declare some object references
		Dim oConn As OleDbConnection = Nothing
		Dim oCmd As OleDbCommand = Nothing
		Dim oAdpt As OleDbDataAdapter = Nothing
		Dim oDS As DataSet = Nothing
		'--- SoftArtisans WordWriter.WordTemplate
		Dim oWW As WordTemplate = Nothing

		'--- This will be the first and last name of the selected recipient
		Dim strFirstName As String = String.Empty
		Dim strLastName As String = String.Empty
		
		'--- The path to our template file
		Dim strTemplatePath As String = Server.MapPath("./DatabaseSelectTemplate.doc")
		
		'--- SQL statement used to retrieve employee address information from the database
		Dim strSQL As String = "SELECT FirstName, LastName, TitleOfCourtesy, Address, City, Region, PostalCode " + _
								"FROM Employees WHERE EmployeeID=?"

		Try
		
			'--- Instantiate and open an OleDbConnection
			oConn = New OleDbConnection(strConnString)
			oConn.Open()

			'--- Instantiate an OleDbCommand and add the employeeID parameter
			oCmd = New OleDbCommand(strSQL, oConn)
			oCmd.Parameters.Add("EmployeeID", employeeID)

			'--- Instantiate an OleDbDataAdapter and fill the dataset
			oAdpt = New OleDbDataAdapter(oCmd)
			oDS = New DataSet()
			oAdpt.Fill(oDS, "employeeIable")
		
			'--- Pull the firstname and lastname from the dataset, we'll use these variables later
			strFirstName = oDS.Tables(0).Rows(0)("FirstName").ToString()
			strLastName = oDS.Tables(0).Rows(0)("LastName").ToString()
			
		
		Catch ex As System.Exception
		
			'--- If an exception was thrown, alert the user and stop
			lblResult.Text = "<B>Error</B><BR>A database exception has occurred.<BR>" + ex.Message
			Return
		
		Finally
		
			'--- Close the database connection
			If Not (oConn Is Nothing) Then
				oConn.Close()
			End If
		
		End Try
		
		Try
		
			'--- Instantiate the WordWriter.WordTemplate object
			oWW = New WordTemplate()
		
			'--- Open the template file
			oWW.Open(strTemplatePath)
		
			'--- Set the datasource with the DataSet containing the recipient information
			oWW.SetDataSource(oDS)
		
			'--- Process the template
			oWW.Process()

			'--- Begin streaming the processed template
			oWW.Save(Page.Response, String.Format("{0}{1}.doc", strLastName, strFirstName), False)
			Response.Flush()
			Response.End()

		Catch ex As System.Exception
		
			'--- Catch any exceptions thrown by WordWriter
			Response.ClearHeaders()
			lblResult.Text = "<B>Error</B><BR>WordWriter could not process your document.<BR>" + ex.Message
			Return
		
		End Try
		
		
	End Sub

</script>

<html>
<head>
<title>SoftArtisans WordWriter</title>
</head>
<body>
<IMG SRC="../../images/wordwriter.jpg" alt="SoftArtisans.WordWriter">
<BR><BR>
<H2><FONT FACE="Arial">Database Letter Sample</FONT></H2>
Select the which recipient from the Northwind Employees table you would like to address a letter to:
<form runat="server">
<asp:DataGrid 
runat="server" 
id="recipientGrid" 
AutoGenerateColumns="False"
BackColor="#e6e6e6" 
Width="300"
HorizontalAlign="Center"
OnItemCommand="Grid_MailTo"
Font-Name="Verdana" 
CellPadding="4"
Font-Size="11pt">
	<HeaderStyle Wrap="False" BackColor="#005a9b" ForeColor="#FFFFFF" Font-Bold="True" HorizontalAlign="Center" />
     <AlternatingItemStyle BackColor="White" /> 

	<Columns>
		<asp:ButtonColumn 
                      
				   HeaderText="Mail to Recipient" 
                       ButtonType="PushButton" 
                       Text="Go" 
                       CommandName="GenerateLetter">
				   <ItemStyle HorizontalAlign="Center" />
		</asp:ButtonColumn>


		<asp:BoundColumn DataField="EmployeeID" visible="False" ReadOnly="True" /> 
		<asp:BoundColumn DataField="LastName" visible="True" HeaderText="Last Name" ReadOnly="True" /> 
		<asp:BoundColumn DataField="FirstName" HeaderText="First Name" ReadOnly="True" /> 
	</Columns>
</asp:DataGrid>
</form>
<div align="center">
<asp:label visible="true" style="color:red" runat="server" id="lblResult" />
</div>
</body>
</html>