<%@ Page Language="C#" Debug="True" EnableSessionState="False" %>
<%@ Import Namespace="SoftArtisans.WordWriter" %>

<script runat="server">
/*
*	SoftArtisans WordWriter.NET FaxCover Sample (C#)
*	------------------------------------------------
*
*	This sample demonstrates how to use WordWriter.NET to create
*	a dynamic fax cover sheet.
*
*	All fax cover sheet information is dynamically obtained
*	from the web form, and populated into the template document by
*	WordWriter.
*/

	//--- This method runs when the submit button on the webform is clicked
	private void btnSubmit_Click(object sender, EventArgs args)
	{
		this.lblResult.Text = "";
		this.ProcessForm();
	}

	//--- This method reads the data from the form and uses WordWriter to populate
	//--- the dynamic fax cover sheet
	private void ProcessForm()
	{
		
		//--- Declare and initialize the WordWriter.WordTemplate object
		WordTemplate oWW = null;

		//--- This string is the file path to the template file
		string strTemplatePath = Server.MapPath("./FaxCoverTemplate.doc");

		//--- Form the required WordWriter name array.  The elements in this array correspond to the names of the
		//--- merge fields in the template, and each element's array index should correpond to an element in the
		//--- value array
		string[] arrNames = {"ToName", "FromName", "Company", "FaxNumber", "PhoneNumber", "Subject", 
						"PageCount", "Comments", "ChkUrgent", "ChkReview", "ChkComment"};

		//--- The value array.  The value of the elements in this array contain info supplied in the web form.
		//--- These values represent the data that will be dynamically populated in the template file
		object[] arrValues = new object[11];
		arrValues[0] = this.txtToName.Value;
		arrValues[1] = this.txtFromName.Value;
		arrValues[2] = this.txtCompany.Value;
		arrValues[3] = this.txtFaxNumber.Value;
		arrValues[4] = this.txtPhoneNumber.Value;
		arrValues[5] = this.txtSubject.Value;
		arrValues[6] = this.txtPageCount.Value;
		arrValues[7] = this.txtComments.Value;
		//--- For the check fields, we'll put an X in the document if checked,
		//--- and an empty string is not.
		arrValues[8] = this.chkUrgent.Checked ? "X" : "";
		arrValues[9] = this.chkReview.Checked ? "X" : "";
		arrValues[10] = this.chkComment.Checked ? "X" : "";
		
		try
		{
			//--- Instantiate the WordWriter.WordTemplate object
			oWW = new WordTemplate();

			//--- Open the template file
			oWW.Open(strTemplatePath);

			//--- Set the datasource with the name and value arrays defined above
			oWW.SetDataSource(arrValues, arrNames);

			//--- Process the template
			oWW.Process();

			//--- Begin streaming the processed template
			oWW.Save(Page.Response, "FaxCoverOutput.doc", false);
			Response.Flush();
			Response.End();
		}
		catch(System.Exception ex)
		{
			//--- Catch any exceptions thrown by WordWriter
			Response.ClearHeaders();
			lblResult.Text = "<B>Error</B><BR>WordWriter could not process your document.<BR>" + ex.Message;
			return;
		}
		
		
	}

</script>

<html>
<head>
<title>SoftArtisans WordWriter</title>
</head>
<body>
<IMG SRC="../../images/wordwriter.jpg" alt="SoftArtisans.WordWriter">
<BR><BR>
<H2><FONT FACE="Arial">Fax Cover Generator</FONT></H2>
<TABLE BORDER=0>
<FORM RUNAT="server">
<TR><TD COLSPAN=3><B>Recipient information</B></TD></TR>
<TR><TD>Name</TD><TD><input type="text" runat="server" id="txtToName"></TD>
<TD><asp:RequiredFieldValidator
                    ControlToValidate="txtToName"
                    Display="Static"
                    ErrorMessage="*"
                    runat="server"/>
</TD>
</TR>
<TR><TD>Company</TD><TD><input type="text" runat="server" id="txtCompany"></TD>
<TD><asp:RequiredFieldValidator 
                    ControlToValidate="txtCompany"
                    Display="Static"
                    ErrorMessage="*"
                    runat="server"/>
</TD>
</TR>
<TR><TD>Fax #</TD><TD><input type="text" runat="server" id="txtFaxNumber"></TD>
<TD><asp:RequiredFieldValidator 
                    ControlToValidate="txtFaxNumber"
                    Display="Static"
                    ErrorMessage="*"
                    runat="server"/>
</TD>
</TR>
<TR><TD>Phone #</TD><TD><input type="text" runat="server" id="txtPhoneNumber"></TD>
<TD><asp:RequiredFieldValidator 
                    ControlToValidate="txtPhoneNumber"
                    Display="Static"
                    ErrorMessage="*"
                    runat="server"/>
</TD>
</TR>
<TR><TD COLSPAN=3><B>Fax information</B></TD></TR>
<TR><TD>From</TD><TD><input type="text" runat="server" id="txtFromName"></TD>
<TD><asp:RequiredFieldValidator 
                    ControlToValidate="txtFromName"
                    Display="Static"
                    ErrorMessage="*"
                    runat="server"/>
</TD>
</TR>

<TR><TD>Subject</TD><TD><input type="text" runat="server" id="txtSubject"></TD>
<TD><asp:RequiredFieldValidator 
                    ControlToValidate="txtSubject"
                    Display="Static"
                    ErrorMessage="*"
                    runat="server"/>
</TD>
</TR>
<TR><TD>Page Count</TD><TD><input type="text" runat="server" id="txtPageCount"></TD>
<TD><asp:RequiredFieldValidator 
                    ControlToValidate="txtPageCount"
                    Display="Static"
                    ErrorMessage="*"
                    runat="server"/>
</TD>
</TR>

<TR><TD>Comments/Notes</TD><TD><textarea runat="server" name="txtComments" id="txtComments"></textarea></TD>
<TD>&nbsp;</TD>
</TR>
<TR><TD COLSPAN=2><input runat="server" type="checkbox" id="chkUrgent"> Urgent 
				<input runat="server" type="checkbox" id="chkReview"> For Review 
				<input runat="server" type="checkbox" id="chkComment"> Please Comment 
</TD>
<TD>&nbsp;</TD>
</TR>
<TR><TD ALIGN=center COLSPAN=3><input type="button" value="Generate Fax Cover" id="btnSubmit" runat="server" OnServerClick="btnSubmit_Click">
</FORM>
</TABLE>
<div align="center">
<asp:label visible="true" style="color:red" runat="server" id="lblResult" />
</div>
</body>
</html>