<%@ Page Language="C#" Debug="True" EnableSessionState="False" %>
<%@ Import Namespace="SoftArtisans.WordWriter" %>

<script runat="server">
/*
*	SoftArtisans WordWriter.NET FormLetter Sample (C#)
*	--------------------------------------------------
*
*	This sample demonstrates how to use WordWriter.NET to create
*	a dynamic form letter.  
*
*	All letter recipient and author information is dynamically obtained
*	from the web form, and populated into the template document by
*	WordWriter.
*/


	//--- This method is invoked when the submit button is clicked
	private void btnSubmit_Click(object sender, EventArgs args)
	{
		this.ProcessForm();
	}

	//--- This method reads all entered form information
	//--- and invokes WordWriter to populate the template file
	private void ProcessForm()
	{
	
		//--- Declare the WordWriter.WordTemplate object
		WordTemplate oWW = null;

		//--- Define the full path to the template file
		string strTemplatePath = Server.MapPath("./FormLetterTemplate.doc");

		//--- Copy values from the form into local string variables
		string recipName = this.txtRecipientName.Value;
		string recipStreetAddr = this.txtRecipientStreetAddr.Value;
		string recipCity = this.txtRecipientCity.Value;
		string recipState = this.txtRecipientState.Value;
		string recipZip = this.txtRecipientZip.Value;
		string authName = this.txtAuthorName.Value;
		string authTitle = this.txtAuthorTitle.Value;

		//--- Form the required WordWriter name array.  The elements in this array correspond to the names of the
		//--- merge fields in the template, and each element's array index should correpond to an element in the
		//--- value array
		string[] arrNames = {"RecipientName", "RecipientStreetAddr", "RecipientCity", "RecipientState", 
						"RecipientZip", "AuthorName", "AuthorTitle"};
		
		//--- The value array.  The value of the elements in this array contain info supplied in the web form.
		//--- These values represent the data that will be dynamically populated in the template file
		object[] arrValues = {recipName, recipStreetAddr, recipCity, recipState, recipZip, authName, authTitle};
		
		try
		{
			//--- Instantiate the WordWriter.WordTemplate object
			oWW = new WordTemplate();

			//--- Open the template file
			oWW.Open(strTemplatePath);

			//--- Set the datasource with the name and value arrays defined above
			oWW.SetDataSource(arrValues, arrNames);
		
			//--- Process the template
			oWW.Process();

			//--- Begin streaming the processed template
			oWW.Save(Page.Response, "FormLetterOutput.doc", false);
			Response.Flush();
			Response.End();
		}
		catch(System.Exception ex)
		{
			//--- Catch any exceptions thrown by WordWriter
			Response.ClearHeaders();
			lblResult.Text = "<B>Error</B><BR>WordWriter could not process your document.<BR>" + ex.Message;
			return;
		}
		
		
	}

</script>

<html>
<head>
<title>SoftArtisans WordWriter</title>
</head>
<body>
<IMG SRC="../../images/wordwriter.jpg" alt="SoftArtisans.WordWriter">
<BR><BR>
<H2><FONT FACE="Arial">Form Letter Generator</FONT></H2>
<TABLE BORDER=0>
<FORM RUNAT="server">
<TR><TD COLSPAN=2><B>Recipient information</B></TD></TR>
<TR><TD>Name</TD><TD><input type="text" runat="server" id="txtRecipientName"></TD>
<TD><asp:RequiredFieldValidator
                    ControlToValidate="txtRecipientName"
                    Display="Static"
                    ErrorMessage="*"
                    runat="server"/>
</TD>
</TR>
<TR><TD>Street address</TD><TD><input type="text" runat="server" id="txtRecipientStreetAddr"></TD>
<TD><asp:RequiredFieldValidator 
                    ControlToValidate="txtRecipientStreetAddr"
                    Display="Static"
                    ErrorMessage="*"
                    runat="server"/>
</TD>
</TR>
<TR><TD>City</TD><TD><input type="text" runat="server" id="txtRecipientCity"></TD>
<TD><asp:RequiredFieldValidator 
                    ControlToValidate="txtRecipientCity"
                    Display="Static"
                    ErrorMessage="*"
                    runat="server"/>
</TD>
</TR>
<TR><TD>State</TD><TD><input type="text" runat="server" id="txtRecipientState"></TD>
<TD><asp:RequiredFieldValidator 
                    ControlToValidate="txtRecipientState"
                    Display="Static"
                    ErrorMessage="*"
                    runat="server"/>
</TD>
</TR>
<TR><TD>Zip</TD><TD><input type="text" runat="server" id="txtRecipientZip"></TD>
<TD><asp:RequiredFieldValidator
                    ControlToValidate="txtRecipientZip"
                    Display="Static"
                    ErrorMessage="*"
                    runat="server"/>
</TD>
</TR>
<TR><TD COLSPAN=2><B>Author information</B></TD></TR>
<TR><TD>Name</TD><TD><input type="text" runat="server" id="txtAuthorName"></TD>
<TD><asp:RequiredFieldValidator 
                    ControlToValidate="txtAuthorName"
                    Display="Static"
                    ErrorMessage="*"
                    runat="server"/>
</TD>
</TR>
<TR><TD>Title</TD><TD><input type="text" runat="server" id="txtAuthorTitle"></TD>
<TD><asp:RequiredFieldValidator 
                    ControlToValidate="txtAuthorTitle"
                    Display="Static"
                    ErrorMessage="*"
                    runat="server"/>
</TD>
</TR>
<TR><TD ALIGN=center COLSPAN=2><input type="button" value="Generate Document" id="btnSubmit" runat="server" OnServerClick="btnSubmit_Click">
</FORM>
</TABLE>
<div align="center">
<asp:label visible="true" style="color:red" runat="server" id="lblResult" />
</div>
</body>
</html>