<%@ Page Language="C#" Debug="True" Trace="False" %>
<%@ Import Namespace="System.Data" %>
<%@ Import Namespace="System.Data.OleDb" %>
<%@ Import Namespace="SoftArtisans.WordWriter" %>

<script runat="server">
/*
*	SoftArtisans WordWriter MultipleDataSource Sample (C#)
*	------------------------------------------------------
*
*	This sample demonstrates how to use WordWriter to populate a Word 
*	table with tabular data.
*	Select a customer from the first dropdown list, 
*	and then select an order ID for which to generate
*	an invoice.
*
*	Copyright (c) 2003 SoftArtisans, Inc.
*	Mail: info@softartisans.com   http://www.softartisans.com
*
*/

	//--- This will be our OleDb connection string
	private string strConnString = String.Empty;

	//--- This method runs when the page loads
	private void Page_Load(Object sender, EventArgs args)
	{
		
		//--- Retrieve the database connection string from the Application collection
		strConnString = "Provider=Microsoft.Jet.OLEDB.4.0;Data source=" +
							Server.MapPath("../../Database/northwind.mdb");

		//--- If the request is not a post-back, populate the data grid
		if(!Page.IsPostBack)
			this.PopulateCustomerDropdown();
	}

	//--- Page_Load calls this method to populate the first customer dropdown
	private void PopulateCustomerDropdown()
	{
		//--- Declare OleDb objects
		OleDbConnection oConn = null;
		OleDbCommand oCmd = null;

		try
		{
			//--- Instantiate and open an OleDbConnection
			oConn = new OleDbConnection(strConnString);
			oConn.Open();

			//--- Instantiate an OleDbCommand with the SQL string
			oCmd = new OleDbCommand("SELECT CustomerID, CompanyName FROM Customers", oConn);
			
			//--- Databind the dropdown
			drpCompanyList.DataSource = oCmd.ExecuteReader();
			drpCompanyList.DataTextField = "CompanyName";
			drpCompanyList.DataValueField = "CustomerID";
			drpCompanyList.DataBind();
		
		}
		catch(Exception ex)
		{
			lblError.Text = "<B>An error has occurred:</B> " + ex.Message;
			return;
		}
		finally
		{
			//--- Close and dispose the connection when we're done with it
			if(oConn!=null)
			{
				oConn.Close();
				oConn.Dispose();
			}
		}	
	}
	
	//--- This method fires when the "Get Orders" button is clicked   
	private void btnGetOrderList_Click(object sender, System.EventArgs e)
	{
		this.PopulateOrdersDropdown();
	}
	
	//--- This method fires when the "Create Document" button is clicked
	private void btnCreateDocument_Click(object sender, EventArgs args)
	{
		this.GenerateDocument();
	}

	//--- Populates the second order ID dropdown with orders from the selected customer
	private void PopulateOrdersDropdown()
	{
		//--- Read the selected value from the customer dropdown
		string customerID = this.drpCompanyList.SelectedValue;
		
		//--- SQL string to get order IDs for a specific customer
		string strSQL = "SELECT OrderID FROM Orders WHERE CustomerID = ?";

		//--- Declare OleDb objects
		OleDbConnection oConn = null;
		OleDbCommand oCmd = null;

		try
		{
			//--- Instantiate and open an OleDbConnection
			oConn = new OleDbConnection(strConnString);
			oConn.Open();

			//--- Create an OleDbCommand
			oCmd = new OleDbCommand(strSQL, oConn);
			oCmd.Parameters.Add("CustomerID", customerID);

			//--- DataBind the dropdown
			drpOrderIDs.DataSource = oCmd.ExecuteReader();
			drpOrderIDs.DataTextField = "OrderID";
			drpOrderIDs.DataValueField = "OrderID";
			drpOrderIDs.DataBind();
		}
		catch(Exception ex)
		{
			lblError.Text = "<B>An error has occurred:</B> " + ex.Message;
			return;
		}
		finally
		{
			//--- Close and dispose the connection when we're done
			if(oConn!=null)
			{
				oConn.Close();
				oConn.Dispose();
			}
		}
		
		//--- Disable the first dropdown and button
		//--- and enable the second set
		btnGetOrderList.Enabled = false;
		drpCompanyList.Enabled = false;
		drpOrderIDs.Enabled = true;
		btnCreateDocument.Enabled = true;
	}
	
	//--- Uses WordWriter to generate the document
	private void GenerateDocument()
	{
		//--- Read the customerID and orderID from the dropdowns
		string orderID = drpOrderIDs.SelectedValue;
		string customerID = drpCompanyList.SelectedValue;

		//--- We'll use this DataSet to hold all the information we need to populate the document
		DataSet ds = new DataSet();

		OleDbConnection oConn = null;

		try
		{
			//--- Open a connection to the database
			//--- We will query the same connection three times for different data
			oConn = new OleDbConnection(strConnString);

			//--- Query the database for customer information
			string sqlCustomer = "SELECT CompanyName, Address, City, Region, PostalCode, Country, ContactName " +
								   "FROM Customers WHERE CustomerID = ?";
											   
			OleDbCommand cmdCustomer = new OleDbCommand(sqlCustomer, oConn);
			cmdCustomer.Parameters.Add("CustomerID", customerID);

			OleDbDataAdapter adptCustomer = new OleDbDataAdapter(cmdCustomer);
			
			adptCustomer.Fill(ds, "CustomerData");

			//--- Query the database for sales representative information
			string sqlSalesRep = "SELECT E.FirstName + ' ' + E.LastName As RepName, E.Title As RepTitle " +
					"FROM Employees E INNER JOIN Orders O ON E.EmployeeID = O.EmployeeID " +
					"WHERE O.OrderID = ? AND O.CustomerID = ?";

			OleDbCommand cmdSalesRep = new OleDbCommand(sqlSalesRep, oConn);
			cmdSalesRep.Parameters.Add("OrderID", orderID);
			cmdSalesRep.Parameters.Add("CustomerID", customerID);

			OleDbDataAdapter adptSalesRep = new OleDbDataAdapter(cmdSalesRep);
			adptSalesRep.Fill(ds, "SalesRepData");
			  
			//--- Query the database for Order Detail information
			string sqlOrders = "SELECT P.ProductID As Item, P.ProductName As Description, (OD.UnitPrice*OD.Quantity)*(1-OD.Discount) As CalcPrice, OD.UnitPrice As Price, OD.Quantity As Qty, OD.Discount, O.OrderDate " +
					"FROM Orders O INNER JOIN (Products P INNER JOIN [Order Details] OD ON P.ProductID = OD.ProductID) ON O.OrderID = OD.OrderID " +
					"WHERE O.OrderID= ? ";

			OleDbCommand cmdOrders = new OleDbCommand(sqlOrders, oConn);
			cmdOrders.Parameters.Add("OrderID", orderID);
				
			OleDbDataAdapter adptOrders = new OleDbDataAdapter(cmdOrders);
			adptOrders.Fill(ds, "OrderDetails");
		}
		catch(Exception ex)
		{
			lblError.Text = "<B>An error has occurred:</B> " + ex.Message;
			return;
		}
		finally
		{
			if(oConn!=null)
			{
				oConn.Close();
				oConn.Dispose();
			}
		}

		//--- Get the count of order detail rows
		int orderDetailRowCount = ds.Tables["OrderDetails"].Rows.Count;

		//--- Template only has 20rows, we can't import more than that
		if(orderDetailRowCount > 20)
			orderDetailRowCount = 20;
		
		//--- Create the names array
		//--- There are 28 rows, six columns, and 11 non-tabular data fields in the template
		string[] names = new string[(28*6) + 11];
		
		//--- These are the non-tabular data fields
		names[0] = "CompanyName";
		names[1] = "Address";
		names[2] = "City";
		names[3] = "Region";
		names[4] = "PostalCode";
		names[5] = "Country";
		names[6] = "ContactName";
		names[7] = "RepName";
		names[8] = "RepTitle";
		names[9] = "OrderNumber";
		names[10] = "OrderDate";
		
		//--- Create the values array
		//--- This should be the same length as the names array
		object[] values = new object[names.Length];

		//--- Populate the values for the eleven non-tabular fields
		values[0] = ds.Tables["CustomerData"].Rows[0]["CompanyName"];
		values[1] = ds.Tables["CustomerData"].Rows[0]["Address"];
		values[2] = ds.Tables["CustomerData"].Rows[0]["City"];
		values[3] = ds.Tables["CustomerData"].Rows[0]["Region"];
		values[4] = ds.Tables["CustomerData"].Rows[0]["PostalCode"];
		values[5] = ds.Tables["CustomerData"].Rows[0]["Country"];
		values[6] = ds.Tables["CustomerData"].Rows[0]["ContactName"];
		values[7] = ds.Tables["SalesRepData"].Rows[0]["RepName"];
		values[8] = ds.Tables["SalesRepData"].Rows[0]["RepTitle"];
		values[9] = orderID;
		values[10] = (DateTime)ds.Tables["OrderDetails"].Rows[0]["OrderDate"];

		//--- We'll use this loop to help us populate the array for the tabular merge fields
		for(int i = 11, j = 1, datarow = 0; i < names.Length; i+=6, j++, datarow++)
		{
			//--- This populates the rest of the names array for the tabular data
			names[i] = "Item" + j.ToString();
			names[i+1] = "Description" + j.ToString();
			names[i+2] = "Price" + j.ToString();
			names[i+3] = "Qty" + j.ToString();
			names[i+4] = "Disc" + j.ToString();
			names[i+5] = "CalcPrice" + j.ToString();
			
			if(datarow < orderDetailRowCount)
			{
				//--- Add values to the value array for tabular data
				values[i] = ds.Tables["OrderDetails"].Rows[datarow]["Item"];
				values[i+1] = ds.Tables["OrderDetails"].Rows[datarow]["Description"];
				values[i+2] = ds.Tables["OrderDetails"].Rows[datarow]["Price"];
				values[i+3] = ds.Tables["OrderDetails"].Rows[datarow]["Qty"];
				values[i+4] = ds.Tables["OrderDetails"].Rows[datarow]["Discount"];
				values[i+5] = ds.Tables["OrderDetails"].Rows[datarow]["CalcPrice"];
			}
			else
			{
				//--- If the row is empty, insert empty strings instead of database data
				values[i] = String.Empty;
				values[i+1] = String.Empty;
				values[i+2] = String.Empty;
				values[i+3] = String.Empty;
				values[i+4] = String.Empty;
				values[i+5] = String.Empty;
			}
		}

		try
		{
			//--- These 5 lines of code use SoftArtisans WordWriter to open and populate
			//--- a Microsoft Word document with the data obtained from the database above

			//--- Instantiate the WordTemplate object
			WordTemplate oWW = new WordTemplate();

			//--- Open the template document
			oWW.Open(Server.MapPath("./MultipleDataSourceTemplate.doc"));

			//--- Set the datasource, passing the names and values arrays created above
			oWW.SetDataSource(values, names);

			//--- Process the document, importing data from the data source
			oWW.Process();

			//--- Stream the populated document to the client
			oWW.Save(Page.Response, "MultipleDataSourceOutput.doc", false);
			Response.Flush();
			Response.End();
		}
		catch(Exception ex)
		{
			lblError.Text = "<B>An error has occurred:</B> " + ex.Message;
			return;
		}
	   
	}

	
	
</script>

<HTML>
	<HEAD>
		<title>WordWriter MultipleDataSource Sample</title>
	</HEAD>
	<body>
	<div>
	<img src="../../images/wordwriter.jpg" alt="SoftArtisans.WordWriter" />
	</div>

	<h3>WordWriter MultipleDataSource sample</h3>
	
	<p>
	This sample demonstrates how to use WordWriter to populate a Word table with tabular data from several different sources.<BR />
	Select a customer from the first dropdown list, and then select an order ID for which to generate
	an invoice.
	</p>
	

		<form runat="server">
			<asp:DropDownList id=drpCompanyList runat="server" /> 
			<asp:Button id="btnGetOrderList" OnClick="btnGetOrderList_Click" runat="server" Text="Get Invoice" />
			<HR NOSHADE />
			<asp:DropDownList id=drpOrderIDs runat="server" Enabled="False" />
			<asp:Button id="btnCreateDocument" OnClick="btnCreateDocument_Click" Enabled="False" runat="server" Text="Generate Document" />
			<P>
			<DIV ALIGN=center>
				<asp:label style="color:red" id="lblError" runat="server" />
			</DIV>
			</P>

		</form>
	</body>
</HTML>
