<%@ Page Language="VB" Explicit="True" Strict="True" Debug="True" Trace="False" %>
<%@ Import Namespace="System.Data" %>
<%@ Import Namespace="System.Data.OleDb" %>
<%@ Import Namespace="SoftArtisans.WordWriter" %>

<script runat="server">
'
'	SoftArtisans WordWriter MultipleDataSource Sample (VB.NET)
'	----------------------------------------------------------
'
'	This sample demonstrates how to use WordWriter to populate a Word 
'	table with tabular data.
'	Select a customer from the first dropdown list, 
'	and then select an order ID for which to generate
'	an invoice.
'
'	Copyright (c) 2003 SoftArtisans, Inc.
'	Mail: info@softartisans.com   http://www.softartisans.com
'

	'--- This method fires when the "Get Orders" button is clicked   
	Private strConnString As String = String.Empty

	'--- This method runs when the page loads
	Private Sub Page_Load(sender As Object, args As EventArgs)
		
		'--- Retrieve the database connection string from the Application collection
		Me.strConnString = "Provider=Microsoft.Jet.OLEDB.4.0;Data source=" + _
							Server.MapPath("../../Database/northwind.mdb")

		'--- If the request is not a post-back, populate the data grid
		If Not Page.IsPostBack Then
			Me.PopulateCustomerDropdown()
		End If
	
	End Sub
	
	'--- Page_Load calls this method to populate the first customer dropdown
	Private Sub PopulateCustomerDropdown()
	
		'--- Declare OleDb objects
		Dim oConn As OleDbConnection = Nothing
		Dim oCmd As OleDbCommand = Nothing

		Try
		
			'--- Instantiate and open an OleDbConnection
			oConn = New OleDbConnection(Me.strConnString)
			oConn.Open()

			'--- Instantiate an OleDbCommand with the SQL string
			oCmd = New OleDbCommand("SELECT CustomerID, CompanyName FROM Customers", oConn)
			
			'--- Databind the dropdown
			drpCompanyList.DataSource = oCmd.ExecuteReader()
			drpCompanyList.DataTextField = "CompanyName"
			drpCompanyList.DataValueField = "CustomerID"
			drpCompanyList.DataBind()
		
		Catch ex As Exception
		
			lblError.Text = "<B>An error has occurred:</B> " + ex.Message
			Return
		
		Finally
		
			'--- Close and dispose the connection when we're done with it
			If Not (oConn Is Nothing) Then
				oConn.Close()
				oConn.Dispose()
			End If
	
		End Try
	
	End Sub 
	 
	'--- This method fires when the "Get Orders" button is clicked   
	Private Sub btnGetOrderList_Click(sender As Object, args As EventArgs)
	
		Me.PopulateOrdersDropdown()
	
	End Sub
	
		
	'--- This method fires when the "Create Document" button is clicked
	Private Sub btnCreateDocument_Click(sender As Object, args As EventArgs)
	
		Me.GenerateDocument()
	
	End Sub

	'--- Populates the second order ID dropdown with orders from the selected customer
	Private Sub PopulateOrdersDropdown()
	
		'--- Read the selected value from the customer dropdown
		Dim customerID As String = Me.drpCompanyList.SelectedValue
		
		'--- SQL string to get order IDs for a specific customer
		Dim strSQL As String = "SELECT OrderID FROM Orders WHERE CustomerID = ?"

		'--- Declare OleDb objects
		Dim oConn As OleDbConnection = Nothing
		Dim oCmd As OleDbCommand = Nothing

		Try
		
			'--- Instantiate and open an OleDbConnection
			oConn = new OleDbConnection(strConnString)
			oConn.Open()

			'--- Create an OleDbCommand
			oCmd = new OleDbCommand(strSQL, oConn)
			oCmd.Parameters.Add("CustomerID", customerID)

			'--- DataBind the dropdown
			drpOrderIDs.DataSource = oCmd.ExecuteReader()
			drpOrderIDs.DataTextField = "OrderID"
			drpOrderIDs.DataValueField = "OrderID"
			drpOrderIDs.DataBind()
		
		Catch ex As Exception
		
			lblError.Text = "<B>An error has occurred:</B> " + ex.Message
			Return

		Finally
		
			'--- Close and dispose the connection when we're done
			If Not (oConn Is Nothing) Then
				oConn.Close()
				oConn.Dispose()
			End If
		
		End Try

		'--- Disable the first dropdown and button
		'--- and enable the second set
		btnGetOrderList.Enabled = False
		drpCompanyList.Enabled = False
		drpOrderIDs.Enabled = True
		btnCreateDocument.Enabled = True
	
	End Sub

	'--- Uses WordWriter to generate the document
	Private Sub GenerateDocument()
	

		
		'--- Read the customerID and orderID from the dropdowns
		Dim orderID As String = drpOrderIDs.SelectedValue
		Dim customerID As String = drpCompanyList.SelectedValue

		'--- We'll use this DataSet to hold all the information we need to populate the document
		Dim ds As New DataSet()

		Dim oConn As OleDbConnection = Nothing

		Try
		
			'--- Open a connection to the database
			'--- We will query the same connection three times for different data
			oConn = new OleDbConnection(strConnString)

			'--- Query the database for customer information
			Dim sqlCustomer As String = "SELECT CompanyName, Address, City, Region, PostalCode, Country, ContactName " + _
								   "FROM Customers WHERE CustomerID = ?"
											   
			Dim cmdCustomer As New OleDbCommand(sqlCustomer, oConn)
			cmdCustomer.Parameters.Add("CustomerID", customerID)

			Dim adptCustomer As New OleDbDataAdapter(cmdCustomer)
			   
			adptCustomer.Fill(ds, "CustomerData")

			'--- Query the database for sales representative information
			Dim sqlSalesRep As String = "SELECT E.FirstName + ' ' + E.LastName As RepName, E.Title As RepTitle " + _
								"FROM Employees E INNER JOIN Orders O ON E.EmployeeID = O.EmployeeID " + _
								"WHERE O.OrderID = ? AND O.CustomerID = ?"

			Dim cmdSalesRep As New OleDbCommand(sqlSalesRep, oConn)
			cmdSalesRep.Parameters.Add("OrderID", orderID)
			cmdSalesRep.Parameters.Add("CustomerID", customerID)

			Dim adptSalesRep As New OleDbDataAdapter(cmdSalesRep)
			adptSalesRep.Fill(ds, "SalesRepData")
			   
			'--- Query the database for Order Detail information
			Dim sqlOrders As String = "SELECT P.ProductID As Item, P.ProductName As Description, (OD.UnitPrice*OD.Quantity)*(1-OD.Discount) As CalcPrice, OD.UnitPrice As Price, OD.Quantity As Qty, OD.Discount, O.OrderDate " + _
								"FROM Orders O INNER JOIN (Products P INNER JOIN [Order Details] OD ON P.ProductID = OD.ProductID) ON O.OrderID = OD.OrderID " + _
								"WHERE O.OrderID= ? "

			Dim cmdOrders As New OleDbCommand(sqlOrders, oConn)
			cmdOrders.Parameters.Add("OrderID", orderID)
				
			Dim adptOrders As New OleDbDataAdapter(cmdOrders)
			adptOrders.Fill(ds, "OrderDetails")
		
		Catch ex As Exception
		
			lblError.Text = "<B>An error has occurred:</B> " + ex.Message
			Return
		
		Finally
		
			If Not (oConn Is Nothing) Then
				oConn.Close()
			End If
		
		End Try
		
		'--- Get the count of order detail rows
		Dim orderDetailRowCount As Integer = ds.Tables("OrderDetails").Rows.Count

		'--- Template only has 20 rows, we can't import more than that
		If (orderDetailRowCount > 20) Then
			orderDetailRowCount = 20
		End If
		
		'--- Create the names array
		'--- There are 28 rows, six columns, and 11 non-tabular data fields in the template
		Dim names((28*6)+10) As String
		
		'--- These are the non-tabular data fields
		names(0) = "CompanyName"
		names(1) = "Address"
		names(2) = "City"
		names(3) = "Region"
		names(4) = "PostalCode"
		names(5) = "Country"
		names(6) = "ContactName"
		names(7) = "RepName"
		names(8) = "RepTitle"
		names(9) = "OrderNumber"
		names(10) = "OrderDate"
		
		'--- Create the values array
		'--- This should be the same length as the names array
		Dim values(names.Length-1) As Object
	
		'--- Populate the values for the eleven non-tabular fields
		values(0) = ds.Tables("CustomerData").Rows(0)("CompanyName")
		values(1) = ds.Tables("CustomerData").Rows(0)("Address")
		values(2) = ds.Tables("CustomerData").Rows(0)("City")
		values(3) = ds.Tables("CustomerData").Rows(0)("Region")
		values(4) = ds.Tables("CustomerData").Rows(0)("PostalCode")
		values(5) = ds.Tables("CustomerData").Rows(0)("Country")
		values(6) = ds.Tables("CustomerData").Rows(0)("ContactName")
		values(7) = ds.Tables("SalesRepData").Rows(0)("RepName")
		values(8) = ds.Tables("SalesRepData").Rows(0)("RepTitle")
		values(9) = orderID
		values(10) = CType(ds.Tables("OrderDetails").Rows(0)("OrderDate"), DateTime)

		Dim j As Integer = 1
		Dim dataRow As Integer = 0
		
		'--- We'll use this loop to help us populate the array for the tabular merge fields
		For i As Integer = 11 To names.Length-1 Step 6
		
			'--- This populates the rest of the names array for the tabular data
			names(i) = "Item" + j.ToString()
			names(i+1) = "Description" + j.ToString()
			names(i+2) = "Price" + j.ToString()
			names(i+3) = "Qty" + j.ToString()
			names(i+4) = "Disc" + j.ToString()
			names(i+5) = "CalcPrice" + j.ToString()
			
			If (datarow < orderDetailRowCount) Then
			
				'--- Add values to the value array for tabular data
				values(i) = ds.Tables("OrderDetails").Rows(datarow)("Item")
				values(i+1) = ds.Tables("OrderDetails").Rows(datarow)("Description")
				values(i+2) = ds.Tables("OrderDetails").Rows(datarow)("Price")
				values(i+3) = ds.Tables("OrderDetails").Rows(datarow)("Qty")
				values(i+4) = ds.Tables("OrderDetails").Rows(datarow)("Discount")
				values(i+5) = ds.Tables("OrderDetails").Rows(datarow)("CalcPrice")
			
			Else
			
				'--- If the row is empty, insert empty strings instead of database data
				values(i) = String.Empty
				values(i+1) = String.Empty
				values(i+2) = String.Empty
				values(i+3) = String.Empty
				values(i+4) = String.Empty
				values(i+5) = String.Empty
			
			End If
		
			j += 1
			dataRow += 1

		Next i

		Try
		
			'--- These 5 lines of code use SoftArtisans WordWriter to open and populate
			'--- a Microsoft Word document with the data obtained from the database above

			'--- Instantiate the WordTemplate object
			Dim oWW As New WordTemplate()

			'--- Open the template document
			oWW.Open(Server.MapPath("./MultipleDataSourceTemplate.doc"))
			
			'--- Set the datasource, passing the names and values arrays created above
			oWW.SetDataSource(values, names)
			
			'--- Process the document, importing data from the data source
			oWW.Process()
			
			'--- Stream the populated document to the client
			oWW.Save(Page.Response, "MultipleDataSourceOutput.doc", False)
			Response.Flush()
			Response.End()
		
		Catch ex As Exception
		
			lblError.Text = "<B>An error has occurred:</B> " + ex.Message
			Return
		
	   End Try
	
	End Sub
	
</script>

<HTML>
	<HEAD>
		<title>WordWriter MultipleDataSource Sample</title>
	</HEAD>
	<body>
	<div>
	<img src="../../images/wordwriter.jpg" alt="SoftArtisans.WordWriter" />
	</div>

	<h3>WordWriter MultipleDataSource sample</h3>
	
	<p>
	This sample demonstrates how to use WordWriter to populate a Word table with tabular data from several different sources.<BR />
	Select a customer from the first dropdown list, and then select an order ID for which to generate
	an invoice.
	</p>
	


		<form runat="server">
			<asp:DropDownList id=drpCompanyList runat="server" /> 
			<asp:Button id="btnGetOrderList" OnClick="btnGetOrderList_Click" runat="server" Text="Get Invoice" />
			<HR NOSHADE />
			<asp:DropDownList id=drpOrderIDs runat="server" Enabled="False" />
			<asp:Button id="btnCreateDocument" OnClick="btnCreateDocument_Click" Enabled="False" runat="server" Text="Generate Document" />
			<P>
			<DIV ALIGN=center>
				<asp:label style="color:red" id="lblError" runat="server" />
			</DIV>
			</P>

		</form>
	</body>
</HTML>
